APIConfigPatterns extension

Adds pattern-matching-related methods to APIConfig.

on

Methods

map<TResult extends Object?>(TResult $default(_APIConfig value)) → TResult

Available on APIConfig, provided by the APIConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_APIConfig value)?) → TResult?

Available on APIConfig, provided by the APIConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_APIConfig value)?, {required TResult orElse()}) → TResult

Available on APIConfig, provided by the APIConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String tag, String? listen, List<ApiService>? services)?, {required TResult orElse()}) → TResult

Available on APIConfig, provided by the APIConfigPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String tag, String? listen, List<ApiService>? services)) → TResult

Available on APIConfig, provided by the APIConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String tag, String? listen, List<ApiService>? services)?) → TResult?

Available on APIConfig, provided by the APIConfigPatterns extension

A variant of when that fallback to returning null