Authenticator class

Inheritance

Constructors

Authenticator({AuthenticatorRequest? request, AuthenticatorResponse? response})
const
Authenticator.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
request AuthenticatorRequest?
final
response AuthenticatorResponse?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited