AuthenticatorRequest class abstract

Available extensions
Annotations
  • @freezed

Constructors

AuthenticatorRequest({String? version, String? method, XrayStringList? path, Map<String, XrayStringList>? headers})
const
factory
AuthenticatorRequest.fromJson(Object? json)
factory

Properties

copyWith → $AuthenticatorRequestCopyWith<AuthenticatorRequest>
Create a copy of AuthenticatorRequest with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, XrayStringList>?
no setterinherited
method String?
no setterinherited
path XrayStringList?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_AuthenticatorRequest value)) → TResult

Available on AuthenticatorRequest, provided by the AuthenticatorRequestPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_AuthenticatorRequest value)?) → TResult?

Available on AuthenticatorRequest, provided by the AuthenticatorRequestPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_AuthenticatorRequest value)?, {required TResult orElse()}) → TResult

Available on AuthenticatorRequest, provided by the AuthenticatorRequestPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? version, String? method, XrayStringList? path, Map<String, XrayStringList>? headers)?, {required TResult orElse()}) → TResult

Available on AuthenticatorRequest, provided by the AuthenticatorRequestPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? version, String? method, XrayStringList? path, Map<String, XrayStringList>? headers)) → TResult

Available on AuthenticatorRequest, provided by the AuthenticatorRequestPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? version, String? method, XrayStringList? path, Map<String, XrayStringList>? headers)?) → TResult?

Available on AuthenticatorRequest, provided by the AuthenticatorRequestPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited