AuthenticatorResponse class abstract

Available extensions
Annotations
  • @freezed

Constructors

AuthenticatorResponse({String? version, String? status, String? reason, Map<String, XrayStringList>? headers})
const
factory
AuthenticatorResponse.fromJson(Object? json)
factory

Properties

copyWith → $AuthenticatorResponseCopyWith<AuthenticatorResponse>
Create a copy of AuthenticatorResponse with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, XrayStringList>?
no setterinherited
reason String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
no setterinherited
version String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_AuthenticatorResponse value)) → TResult

Available on AuthenticatorResponse, provided by the AuthenticatorResponsePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_AuthenticatorResponse value)?) → TResult?

Available on AuthenticatorResponse, provided by the AuthenticatorResponsePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_AuthenticatorResponse value)?, {required TResult orElse()}) → TResult

Available on AuthenticatorResponse, provided by the AuthenticatorResponsePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? version, String? status, String? reason, Map<String, XrayStringList>? headers)?, {required TResult orElse()}) → TResult

Available on AuthenticatorResponse, provided by the AuthenticatorResponsePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? version, String? status, String? reason, Map<String, XrayStringList>? headers)) → TResult

Available on AuthenticatorResponse, provided by the AuthenticatorResponsePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? version, String? status, String? reason, Map<String, XrayStringList>? headers)?) → TResult?

Available on AuthenticatorResponse, provided by the AuthenticatorResponsePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited