BalancingRule class abstract

Available extensions
Annotations
  • @freezed

Constructors

BalancingRule({required String tag, @JsonKey.new(name: 'selector') required XrayStringList selectors, StrategyConfig? strategy, String? fallbackTag})
const
factory
BalancingRule.fromJson(Object? json)
factory

Properties

copyWith → $BalancingRuleCopyWith<BalancingRule>
Create a copy of BalancingRule with the given fields replaced by the non-null parameter values.
no setterinherited
fallbackTag String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectors XrayStringList
no setterinherited
strategy StrategyConfig?
no setterinherited
tag String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_BalancingRule value)) → TResult

Available on BalancingRule, provided by the BalancingRulePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_BalancingRule value)?) → TResult?

Available on BalancingRule, provided by the BalancingRulePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_BalancingRule value)?, {required TResult orElse()}) → TResult

Available on BalancingRule, provided by the BalancingRulePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String tag, XrayStringList selectors, StrategyConfig? strategy, String? fallbackTag)?, {required TResult orElse()}) → TResult

Available on BalancingRule, provided by the BalancingRulePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String tag, XrayStringList selectors, StrategyConfig? strategy, String? fallbackTag)) → TResult

Available on BalancingRule, provided by the BalancingRulePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String tag, XrayStringList selectors, StrategyConfig? strategy, String? fallbackTag)?) → TResult?

Available on BalancingRule, provided by the BalancingRulePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited