DNSOutboundConfigPatterns extension

Adds pattern-matching-related methods to DNSOutboundConfig.

on

Methods

map<TResult extends Object?>(TResult $default(_DNSOutboundConfig value)) → TResult

Available on DNSOutboundConfig, provided by the DNSOutboundConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_DNSOutboundConfig value)?) → TResult?

Available on DNSOutboundConfig, provided by the DNSOutboundConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_DNSOutboundConfig value)?, {required TResult orElse()}) → TResult

Available on DNSOutboundConfig, provided by the DNSOutboundConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(XrayNetwork? network, XrayAddress? address, int? port, int? userLevel, List<DNSOutboundRuleConfig>? rules, String? nonIPQuery, List<int>? blockTypes)?, {required TResult orElse()}) → TResult

Available on DNSOutboundConfig, provided by the DNSOutboundConfigPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(XrayNetwork? network, XrayAddress? address, int? port, int? userLevel, List<DNSOutboundRuleConfig>? rules, String? nonIPQuery, List<int>? blockTypes)) → TResult

Available on DNSOutboundConfig, provided by the DNSOutboundConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(XrayNetwork? network, XrayAddress? address, int? port, int? userLevel, List<DNSOutboundRuleConfig>? rules, String? nonIPQuery, List<int>? blockTypes)?) → TResult?

Available on DNSOutboundConfig, provided by the DNSOutboundConfigPatterns extension

A variant of when that fallback to returning null