DokodemoConfig class abstract

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

DokodemoConfig({XrayAddress? address, int? port, Map<String, String>? portMap, @JsonKey.new(name: 'network') XrayNetworkList? network, bool? followRedirect, int? userLevel})
const
factory
DokodemoConfig.fromJson(Object? json)
factory

Properties

address XrayAddress?
no setterinherited
copyWith → $DokodemoConfigCopyWith<DokodemoConfig>
Create a copy of DokodemoConfig with the given fields replaced by the non-null parameter values.
no setterinherited
followRedirect bool?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
network XrayNetworkList?
no setterinherited
port int?
no setterinherited
portMap Map<String, String>?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userLevel int?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_DokodemoConfig value)) → TResult

Available on DokodemoConfig, provided by the DokodemoConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_DokodemoConfig value)?) → TResult?

Available on DokodemoConfig, provided by the DokodemoConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_DokodemoConfig value)?, {required TResult orElse()}) → TResult

Available on DokodemoConfig, provided by the DokodemoConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(XrayAddress? address, int? port, Map<String, String>? portMap, XrayNetworkList? network, bool? followRedirect, int? userLevel)?, {required TResult orElse()}) → TResult

Available on DokodemoConfig, provided by the DokodemoConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(XrayAddress? address, int? port, Map<String, String>? portMap, XrayNetworkList? network, bool? followRedirect, int? userLevel)) → TResult

Available on DokodemoConfig, provided by the DokodemoConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(XrayAddress? address, int? port, Map<String, String>? portMap, XrayNetworkList? network, bool? followRedirect, int? userLevel)?) → TResult?

Available on DokodemoConfig, provided by the DokodemoConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited