Fragment class abstract

Available extensions
Annotations
  • @freezed

Constructors

Fragment({String? packets, XrayInt32Range? length, XrayInt32Range? interval, XrayInt32Range? maxSplit})
const
factory
Fragment.fromJson(Object? json)
factory

Properties

copyWith → $FragmentCopyWith<Fragment>
Create a copy of Fragment with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
interval XrayInt32Range?
no setterinherited
length XrayInt32Range?
no setterinherited
maxSplit XrayInt32Range?
no setterinherited
packets String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Fragment value)) → TResult

Available on Fragment, provided by the FragmentPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Fragment value)?) → TResult?

Available on Fragment, provided by the FragmentPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Fragment value)?, {required TResult orElse()}) → TResult

Available on Fragment, provided by the FragmentPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? packets, XrayInt32Range? length, XrayInt32Range? interval, XrayInt32Range? maxSplit)?, {required TResult orElse()}) → TResult

Available on Fragment, provided by the FragmentPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? packets, XrayInt32Range? length, XrayInt32Range? interval, XrayInt32Range? maxSplit)) → TResult

Available on Fragment, provided by the FragmentPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? packets, XrayInt32Range? length, XrayInt32Range? interval, XrayInt32Range? maxSplit)?) → TResult?

Available on Fragment, provided by the FragmentPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited