FreedomConfig class abstract

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

FreedomConfig({XrayTargetStrategy? targetStrategy, XrayTargetStrategy? domainStrategy, String? redirect, int? userLevel, Fragment? fragment, Noise? noise, List<Noise>? noises, int? proxyProtocol, XrayStringList? ipsBlocked})
const
factory
FreedomConfig.fromJson(Object? json)
factory

Properties

copyWith → $FreedomConfigCopyWith<FreedomConfig>
Create a copy of FreedomConfig with the given fields replaced by the non-null parameter values.
no setterinherited
domainStrategy XrayTargetStrategy?
no setterinherited
fragment Fragment?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
ipsBlocked XrayStringList?
no setterinherited
noise Noise?
no setterinherited
noises List<Noise>?
no setterinherited
proxyProtocol int?
no setterinherited
redirect String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetStrategy XrayTargetStrategy?
no setterinherited
userLevel int?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_FreedomConfig value)) → TResult

Available on FreedomConfig, provided by the FreedomConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_FreedomConfig value)?) → TResult?

Available on FreedomConfig, provided by the FreedomConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_FreedomConfig value)?, {required TResult orElse()}) → TResult

Available on FreedomConfig, provided by the FreedomConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(XrayTargetStrategy? targetStrategy, XrayTargetStrategy? domainStrategy, String? redirect, int? userLevel, Fragment? fragment, Noise? noise, List<Noise>? noises, int? proxyProtocol, XrayStringList? ipsBlocked)?, {required TResult orElse()}) → TResult

Available on FreedomConfig, provided by the FreedomConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(XrayTargetStrategy? targetStrategy, XrayTargetStrategy? domainStrategy, String? redirect, int? userLevel, Fragment? fragment, Noise? noise, List<Noise>? noises, int? proxyProtocol, XrayStringList? ipsBlocked)) → TResult

Available on FreedomConfig, provided by the FreedomConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(XrayTargetStrategy? targetStrategy, XrayTargetStrategy? domainStrategy, String? redirect, int? userLevel, Fragment? fragment, Noise? noise, List<Noise>? noises, int? proxyProtocol, XrayStringList? ipsBlocked)?) → TResult?

Available on FreedomConfig, provided by the FreedomConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited