FreedomFinalRuleConfig class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- FreedomFinalRuleConfig({String? action, XrayNetworkList? network, XrayPortList? port, XrayStringList? ip, XrayInt32Range? blockDelay})
-
constfactory
- FreedomFinalRuleConfig.fromJson(Object? json)
-
factory
Properties
- action → String?
-
no setterinherited
- blockDelay → XrayInt32Range?
-
no setterinherited
-
copyWith
→ $FreedomFinalRuleConfigCopyWith<
FreedomFinalRuleConfig> -
Create a copy of FreedomFinalRuleConfig
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- ip → XrayStringList?
-
no setterinherited
- network → XrayNetworkList?
-
no setterinherited
- port → XrayPortList?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_FreedomFinalRuleConfig value)) → TResult -
Available on FreedomFinalRuleConfig, provided by the FreedomFinalRuleConfigPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_FreedomFinalRuleConfig value)?) → TResult? -
Available on FreedomFinalRuleConfig, provided by the FreedomFinalRuleConfigPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_FreedomFinalRuleConfig value)?, {required TResult orElse()}) → TResult -
Available on FreedomFinalRuleConfig, provided by the FreedomFinalRuleConfigPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? action, XrayNetworkList? network, XrayPortList? port, XrayStringList? ip, XrayInt32Range? blockDelay)?, {required TResult orElse()}) → TResult -
Available on FreedomFinalRuleConfig, provided by the FreedomFinalRuleConfigPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? action, XrayNetworkList? network, XrayPortList? port, XrayStringList? ip, XrayInt32Range? blockDelay)) → TResult -
Available on FreedomFinalRuleConfig, provided by the FreedomFinalRuleConfigPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? action, XrayNetworkList? network, XrayPortList? port, XrayStringList? ip, XrayInt32Range? blockDelay)?) → TResult? -
Available on FreedomFinalRuleConfig, provided by the FreedomFinalRuleConfigPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited