FreedomFinalRuleConfigPatterns extension

Adds pattern-matching-related methods to FreedomFinalRuleConfig.

on

Methods

map<TResult extends Object?>(TResult $default(_FreedomFinalRuleConfig value)) → TResult

Available on FreedomFinalRuleConfig, provided by the FreedomFinalRuleConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_FreedomFinalRuleConfig value)?) → TResult?

Available on FreedomFinalRuleConfig, provided by the FreedomFinalRuleConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_FreedomFinalRuleConfig value)?, {required TResult orElse()}) → TResult

Available on FreedomFinalRuleConfig, provided by the FreedomFinalRuleConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? action, XrayNetworkList? network, XrayPortList? port, XrayStringList? ip, XrayInt32Range? blockDelay)?, {required TResult orElse()}) → TResult

Available on FreedomFinalRuleConfig, provided by the FreedomFinalRuleConfigPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String? action, XrayNetworkList? network, XrayPortList? port, XrayStringList? ip, XrayInt32Range? blockDelay)) → TResult

Available on FreedomFinalRuleConfig, provided by the FreedomFinalRuleConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? action, XrayNetworkList? network, XrayPortList? port, XrayStringList? ip, XrayInt32Range? blockDelay)?) → TResult?

Available on FreedomFinalRuleConfig, provided by the FreedomFinalRuleConfigPatterns extension

A variant of when that fallback to returning null