GRPCConfig class abstract

Available extensions
Annotations
  • @freezed

Constructors

GRPCConfig({String? authority, String? serviceName, bool? multiMode, @JsonKey.new(name: 'idle_timeout') int? idleTimeout, @JsonKey.new(name: 'health_check_timeout') int? healthCheckTimeout, @JsonKey.new(name: 'permit_without_stream') bool? permitWithoutStream, @JsonKey.new(name: 'initial_windows_size') int? initialWindowsSize, @JsonKey.new(name: 'user_agent') String? userAgent})
const
factory
GRPCConfig.fromJson(Object? json)
factory

Properties

authority String?
no setterinherited
copyWith → $GRPCConfigCopyWith<GRPCConfig>
Create a copy of GRPCConfig with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
healthCheckTimeout int?
no setterinherited
idleTimeout int?
no setterinherited
initialWindowsSize int?
no setterinherited
multiMode bool?
no setterinherited
permitWithoutStream bool?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceName String?
no setterinherited
userAgent String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_GRPCConfig value)) → TResult

Available on GRPCConfig, provided by the GRPCConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_GRPCConfig value)?) → TResult?

Available on GRPCConfig, provided by the GRPCConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_GRPCConfig value)?, {required TResult orElse()}) → TResult

Available on GRPCConfig, provided by the GRPCConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? authority, String? serviceName, bool? multiMode, int? idleTimeout, int? healthCheckTimeout, bool? permitWithoutStream, int? initialWindowsSize, String? userAgent)?, {required TResult orElse()}) → TResult

Available on GRPCConfig, provided by the GRPCConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? authority, String? serviceName, bool? multiMode, int? idleTimeout, int? healthCheckTimeout, bool? permitWithoutStream, int? initialWindowsSize, String? userAgent)) → TResult

Available on GRPCConfig, provided by the GRPCConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? authority, String? serviceName, bool? multiMode, int? idleTimeout, int? healthCheckTimeout, bool? permitWithoutStream, int? initialWindowsSize, String? userAgent)?) → TResult?

Available on GRPCConfig, provided by the GRPCConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited