GeodataConfig class abstract

Available extensions
Annotations
  • @freezed

Constructors

GeodataConfig({String? cron, String? outbound, List<GeodataAssetConfig>? assets})
const
factory
GeodataConfig.fromJson(Object? json)
factory

Properties

assets List<GeodataAssetConfig>?
no setterinherited
copyWith → $GeodataConfigCopyWith<GeodataConfig>
Create a copy of GeodataConfig with the given fields replaced by the non-null parameter values.
no setterinherited
cron String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
outbound String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_GeodataConfig value)) → TResult

Available on GeodataConfig, provided by the GeodataConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_GeodataConfig value)?) → TResult?

Available on GeodataConfig, provided by the GeodataConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_GeodataConfig value)?, {required TResult orElse()}) → TResult

Available on GeodataConfig, provided by the GeodataConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? cron, String? outbound, List<GeodataAssetConfig>? assets)?, {required TResult orElse()}) → TResult

Available on GeodataConfig, provided by the GeodataConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? cron, String? outbound, List<GeodataAssetConfig>? assets)) → TResult

Available on GeodataConfig, provided by the GeodataConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? cron, String? outbound, List<GeodataAssetConfig>? assets)?) → TResult?

Available on GeodataConfig, provided by the GeodataConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited