GeodataConfigPatterns extension

Adds pattern-matching-related methods to GeodataConfig.

on

Methods

map<TResult extends Object?>(TResult $default(_GeodataConfig value)) → TResult

Available on GeodataConfig, provided by the GeodataConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_GeodataConfig value)?) → TResult?

Available on GeodataConfig, provided by the GeodataConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_GeodataConfig value)?, {required TResult orElse()}) → TResult

Available on GeodataConfig, provided by the GeodataConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? cron, String? outbound, List<GeodataAssetConfig>? assets)?, {required TResult orElse()}) → TResult

Available on GeodataConfig, provided by the GeodataConfigPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String? cron, String? outbound, List<GeodataAssetConfig>? assets)) → TResult

Available on GeodataConfig, provided by the GeodataConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? cron, String? outbound, List<GeodataAssetConfig>? assets)?) → TResult?

Available on GeodataConfig, provided by the GeodataConfigPatterns extension

A variant of when that fallback to returning null