HTTPClientConfig class abstract

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

HTTPClientConfig({XrayAddress? address, int? port, int? level, String? email, @JsonKey.new(name: 'user') String? username, @JsonKey.new(name: 'pass') String? password, List<HTTPRemoteConfig>? servers, Map<String, String>? headers})
const
factory
HTTPClientConfig.fromJson(Object? json)
factory
HTTPClientConfig.single({required XrayAddress address, required int port, int? level, String? email, String? username, String? password, Map<String, String>? headers})
factory

Properties

address XrayAddress?
no setterinherited
copyWith → $HTTPClientConfigCopyWith<HTTPClientConfig>
Create a copy of HTTPClientConfig with the given fields replaced by the non-null parameter values.
no setterinherited
email String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>?
no setterinherited
level int?
no setterinherited
password String?
no setterinherited
port int?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
servers List<HTTPRemoteConfig>?
no setterinherited
username String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_HTTPClientConfig value)) → TResult

Available on HTTPClientConfig, provided by the HTTPClientConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_HTTPClientConfig value)?) → TResult?

Available on HTTPClientConfig, provided by the HTTPClientConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_HTTPClientConfig value)?, {required TResult orElse()}) → TResult

Available on HTTPClientConfig, provided by the HTTPClientConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(XrayAddress? address, int? port, int? level, String? email, String? username, String? password, List<HTTPRemoteConfig>? servers, Map<String, String>? headers)?, {required TResult orElse()}) → TResult

Available on HTTPClientConfig, provided by the HTTPClientConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(XrayAddress? address, int? port, int? level, String? email, String? username, String? password, List<HTTPRemoteConfig>? servers, Map<String, String>? headers)) → TResult

Available on HTTPClientConfig, provided by the HTTPClientConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(XrayAddress? address, int? port, int? level, String? email, String? username, String? password, List<HTTPRemoteConfig>? servers, Map<String, String>? headers)?) → TResult?

Available on HTTPClientConfig, provided by the HTTPClientConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited