HeaderCustomTCP class abstract

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

HeaderCustomTCP({List<List<TCPItem>>? clients, List<List<TCPItem>>? servers, List<List<TCPItem>>? errors})
const
factory
HeaderCustomTCP.fromJson(Object? json)
factory

Properties

clients List<List<TCPItem>>?
no setterinherited
copyWith → $HeaderCustomTCPCopyWith<HeaderCustomTCP>
Create a copy of HeaderCustomTCP with the given fields replaced by the non-null parameter values.
no setterinherited
errors List<List<TCPItem>>?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
servers List<List<TCPItem>>?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_HeaderCustomTCP value)) → TResult

Available on HeaderCustomTCP, provided by the HeaderCustomTCPPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_HeaderCustomTCP value)?) → TResult?

Available on HeaderCustomTCP, provided by the HeaderCustomTCPPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_HeaderCustomTCP value)?, {required TResult orElse()}) → TResult

Available on HeaderCustomTCP, provided by the HeaderCustomTCPPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(List<List<TCPItem>>? clients, List<List<TCPItem>>? servers, List<List<TCPItem>>? errors)?, {required TResult orElse()}) → TResult

Available on HeaderCustomTCP, provided by the HeaderCustomTCPPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(List<List<TCPItem>>? clients, List<List<TCPItem>>? servers, List<List<TCPItem>>? errors)) → TResult

Available on HeaderCustomTCP, provided by the HeaderCustomTCPPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(List<List<TCPItem>>? clients, List<List<TCPItem>>? servers, List<List<TCPItem>>? errors)?) → TResult?

Available on HeaderCustomTCP, provided by the HeaderCustomTCPPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited