HeaderCustomUDP class abstract

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

HeaderCustomUDP({String? mode, @JsonKey.new(name: 'client') List<UDPItem>? client, @JsonKey.new(name: 'server') List<UDPItem>? server})
const
factory
HeaderCustomUDP.fromJson(Object? json)
factory

Properties

client List<UDPItem>?
no setterinherited
copyWith → $HeaderCustomUDPCopyWith<HeaderCustomUDP>
Create a copy of HeaderCustomUDP with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
mode String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
server List<UDPItem>?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_HeaderCustomUDP value)) → TResult

Available on HeaderCustomUDP, provided by the HeaderCustomUDPPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_HeaderCustomUDP value)?) → TResult?

Available on HeaderCustomUDP, provided by the HeaderCustomUDPPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_HeaderCustomUDP value)?, {required TResult orElse()}) → TResult

Available on HeaderCustomUDP, provided by the HeaderCustomUDPPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? mode, List<UDPItem>? client, List<UDPItem>? server)?, {required TResult orElse()}) → TResult

Available on HeaderCustomUDP, provided by the HeaderCustomUDPPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? mode, List<UDPItem>? client, List<UDPItem>? server)) → TResult

Available on HeaderCustomUDP, provided by the HeaderCustomUDPPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? mode, List<UDPItem>? client, List<UDPItem>? server)?) → TResult?

Available on HeaderCustomUDP, provided by the HeaderCustomUDPPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited