HealthCheckSettings class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- HealthCheckSettings({String? destination, String? connectivity, XrayDuration? interval, @JsonKey.new(name: 'sampling') int? samplingCount, XrayDuration? timeout, String? httpMethod})
-
constfactory
- HealthCheckSettings.fromJson(Object? json)
-
factory
Properties
- connectivity → String?
-
no setterinherited
-
copyWith
→ $HealthCheckSettingsCopyWith<
HealthCheckSettings> -
Create a copy of HealthCheckSettings
with the given fields replaced by the non-null parameter values.
no setterinherited
- destination → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpMethod → String?
-
no setterinherited
- interval → XrayDuration?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- samplingCount → int?
-
no setterinherited
- timeout → XrayDuration?
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_HealthCheckSettings value)) → TResult -
Available on HealthCheckSettings, provided by the HealthCheckSettingsPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_HealthCheckSettings value)?) → TResult? -
Available on HealthCheckSettings, provided by the HealthCheckSettingsPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_HealthCheckSettings value)?, {required TResult orElse()}) → TResult -
Available on HealthCheckSettings, provided by the HealthCheckSettingsPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? destination, String? connectivity, XrayDuration? interval, int? samplingCount, XrayDuration? timeout, String? httpMethod)?, {required TResult orElse()}) → TResult -
Available on HealthCheckSettings, provided by the HealthCheckSettingsPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? destination, String? connectivity, XrayDuration? interval, int? samplingCount, XrayDuration? timeout, String? httpMethod)) → TResult -
Available on HealthCheckSettings, provided by the HealthCheckSettingsPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? destination, String? connectivity, XrayDuration? interval, int? samplingCount, XrayDuration? timeout, String? httpMethod)?) → TResult? -
Available on HealthCheckSettings, provided by the HealthCheckSettingsPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited