HostAddress class sealed

Implementers

Constructors

HostAddress.fromJson(Object? json)
factory
HostAddress.list(List<XrayAddress> addresses)
const
factory
HostAddress.single(XrayAddress address)
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited