HostsWrapper class abstract

Available extensions
Annotations
  • @freezed

Constructors

HostsWrapper({required Map<String, HostAddress> hosts})
const
factory
HostsWrapper.fromJson(Object? json)
factory

Properties

copyWith → $HostsWrapperCopyWith<HostsWrapper>
Create a copy of HostsWrapper with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hosts Map<String, HostAddress>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_HostsWrapper value)) → TResult

Available on HostsWrapper, provided by the HostsWrapperPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_HostsWrapper value)?) → TResult?

Available on HostsWrapper, provided by the HostsWrapperPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_HostsWrapper value)?, {required TResult orElse()}) → TResult

Available on HostsWrapper, provided by the HostsWrapperPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(Map<String, HostAddress> hosts)?, {required TResult orElse()}) → TResult

Available on HostsWrapper, provided by the HostsWrapperPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(Map<String, HostAddress> hosts)) → TResult

Available on HostsWrapper, provided by the HostsWrapperPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(Map<String, HostAddress> hosts)?) → TResult?

Available on HostsWrapper, provided by the HostsWrapperPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited