HttpUpgradeConfig class abstract

Available extensions
Annotations
  • @freezed

Constructors

HttpUpgradeConfig({String? host, String? path, Map<String, String>? headers, bool? acceptProxyProtocol})
const
factory
HttpUpgradeConfig.fromJson(Object? json)
factory

Properties

acceptProxyProtocol bool?
no setterinherited
copyWith → $HttpUpgradeConfigCopyWith<HttpUpgradeConfig>
Create a copy of HttpUpgradeConfig with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>?
no setterinherited
host String?
no setterinherited
path String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_HttpUpgradeConfig value)) → TResult

Available on HttpUpgradeConfig, provided by the HttpUpgradeConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_HttpUpgradeConfig value)?) → TResult?

Available on HttpUpgradeConfig, provided by the HttpUpgradeConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_HttpUpgradeConfig value)?, {required TResult orElse()}) → TResult

Available on HttpUpgradeConfig, provided by the HttpUpgradeConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? host, String? path, Map<String, String>? headers, bool? acceptProxyProtocol)?, {required TResult orElse()}) → TResult

Available on HttpUpgradeConfig, provided by the HttpUpgradeConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? host, String? path, Map<String, String>? headers, bool? acceptProxyProtocol)) → TResult

Available on HttpUpgradeConfig, provided by the HttpUpgradeConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? host, String? path, Map<String, String>? headers, bool? acceptProxyProtocol)?) → TResult?

Available on HttpUpgradeConfig, provided by the HttpUpgradeConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited