HysteriaClientConfig class abstract

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

HysteriaClientConfig({required int version, required XrayAddress address, required int port})
const
factory
HysteriaClientConfig.fromJson(Object? json)
factory

Properties

address XrayAddress
no setterinherited
copyWith → $HysteriaClientConfigCopyWith<HysteriaClientConfig>
Create a copy of HysteriaClientConfig with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
port int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_HysteriaClientConfig value)) → TResult

Available on HysteriaClientConfig, provided by the HysteriaClientConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_HysteriaClientConfig value)?) → TResult?

Available on HysteriaClientConfig, provided by the HysteriaClientConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_HysteriaClientConfig value)?, {required TResult orElse()}) → TResult

Available on HysteriaClientConfig, provided by the HysteriaClientConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int version, XrayAddress address, int port)?, {required TResult orElse()}) → TResult

Available on HysteriaClientConfig, provided by the HysteriaClientConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int version, XrayAddress address, int port)) → TResult

Available on HysteriaClientConfig, provided by the HysteriaClientConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int version, XrayAddress address, int port)?) → TResult?

Available on HysteriaClientConfig, provided by the HysteriaClientConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited