HysteriaServerConfig class abstract

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

HysteriaServerConfig({int? version, @JsonKey.new(name: 'clients') List<HysteriaUserConfig>? users})
const
factory
HysteriaServerConfig.fromJson(Object? json)
factory

Properties

copyWith → $HysteriaServerConfigCopyWith<HysteriaServerConfig>
Create a copy of HysteriaServerConfig with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
users List<HysteriaUserConfig>?
no setterinherited
version int?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_HysteriaServerConfig value)) → TResult

Available on HysteriaServerConfig, provided by the HysteriaServerConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_HysteriaServerConfig value)?) → TResult?

Available on HysteriaServerConfig, provided by the HysteriaServerConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_HysteriaServerConfig value)?, {required TResult orElse()}) → TResult

Available on HysteriaServerConfig, provided by the HysteriaServerConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int? version, List<HysteriaUserConfig>? users)?, {required TResult orElse()}) → TResult

Available on HysteriaServerConfig, provided by the HysteriaServerConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int? version, List<HysteriaUserConfig>? users)) → TResult

Available on HysteriaServerConfig, provided by the HysteriaServerConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int? version, List<HysteriaUserConfig>? users)?) → TResult?

Available on HysteriaServerConfig, provided by the HysteriaServerConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited