InboundDetourConfig class abstract

Available extensions
Annotations
  • @freezed

Constructors

InboundDetourConfig({required String protocol, XrayPortList? port, XrayAddress? listen, XrayInboundSettings? settings, String? tag, StreamConfig? streamSettings, SniffingConfig? sniffing})
const
factory
InboundDetourConfig.fromJson(Object? json)
factory
InboundDetourConfig.fromProtocol({required XrayInboundProtocol protocol, XrayPortList? port, XrayAddress? listen, XrayInboundSettings? settings, String? tag, StreamConfig? streamSettings, SniffingConfig? sniffing})
factory
InboundDetourConfig.http({required XrayPortList port, required HTTPServerConfig settings, XrayAddress? listen, String? tag, StreamConfig? streamSettings, SniffingConfig? sniffing})
factory
InboundDetourConfig.shadowsocks({required XrayPortList port, required ShadowsocksServerConfig settings, XrayAddress? listen, String? tag, StreamConfig? streamSettings, SniffingConfig? sniffing})
factory
InboundDetourConfig.socks({required XrayPortList port, required SocksServerConfig settings, XrayAddress? listen, String? tag, StreamConfig? streamSettings, SniffingConfig? sniffing})
factory
InboundDetourConfig.trojan({required XrayPortList port, required TrojanServerConfig settings, XrayAddress? listen, String? tag, StreamConfig? streamSettings, SniffingConfig? sniffing})
factory
InboundDetourConfig.tun({required TunConfig settings, String? tag, StreamConfig? streamSettings, SniffingConfig? sniffing})
factory
InboundDetourConfig.vless({required XrayPortList port, required VLessInboundConfig settings, XrayAddress? listen, String? tag, StreamConfig? streamSettings, SniffingConfig? sniffing})
factory
InboundDetourConfig.vmess({required XrayPortList port, required VMessInboundConfig settings, XrayAddress? listen, String? tag, StreamConfig? streamSettings, SniffingConfig? sniffing})
factory

Properties

copyWith → $InboundDetourConfigCopyWith<InboundDetourConfig>
Create a copy of InboundDetourConfig with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
listen XrayAddress?
no setterinherited
port XrayPortList?
no setterinherited
protocol String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings XrayInboundSettings?
no setterinherited
sniffing SniffingConfig?
no setterinherited
streamSettings StreamConfig?
no setterinherited
tag String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_InboundDetourConfig value)) → TResult

Available on InboundDetourConfig, provided by the InboundDetourConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_InboundDetourConfig value)?) → TResult?

Available on InboundDetourConfig, provided by the InboundDetourConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_InboundDetourConfig value)?, {required TResult orElse()}) → TResult

Available on InboundDetourConfig, provided by the InboundDetourConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String protocol, XrayPortList? port, XrayAddress? listen, XrayInboundSettings? settings, String? tag, StreamConfig? streamSettings, SniffingConfig? sniffing)?, {required TResult orElse()}) → TResult

Available on InboundDetourConfig, provided by the InboundDetourConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String protocol, XrayPortList? port, XrayAddress? listen, XrayInboundSettings? settings, String? tag, StreamConfig? streamSettings, SniffingConfig? sniffing)) → TResult

Available on InboundDetourConfig, provided by the InboundDetourConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String protocol, XrayPortList? port, XrayAddress? listen, XrayInboundSettings? settings, String? tag, StreamConfig? streamSettings, SniffingConfig? sniffing)?) → TResult?

Available on InboundDetourConfig, provided by the InboundDetourConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited