InboundDetourConfigPatterns extension

Adds pattern-matching-related methods to InboundDetourConfig.

on

Methods

map<TResult extends Object?>(TResult $default(_InboundDetourConfig value)) → TResult

Available on InboundDetourConfig, provided by the InboundDetourConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_InboundDetourConfig value)?) → TResult?

Available on InboundDetourConfig, provided by the InboundDetourConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_InboundDetourConfig value)?, {required TResult orElse()}) → TResult

Available on InboundDetourConfig, provided by the InboundDetourConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String protocol, XrayPortList? port, XrayAddress? listen, XrayInboundSettings? settings, String? tag, StreamConfig? streamSettings, SniffingConfig? sniffing)?, {required TResult orElse()}) → TResult

Available on InboundDetourConfig, provided by the InboundDetourConfigPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String protocol, XrayPortList? port, XrayAddress? listen, XrayInboundSettings? settings, String? tag, StreamConfig? streamSettings, SniffingConfig? sniffing)) → TResult

Available on InboundDetourConfig, provided by the InboundDetourConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String protocol, XrayPortList? port, XrayAddress? listen, XrayInboundSettings? settings, String? tag, StreamConfig? streamSettings, SniffingConfig? sniffing)?) → TResult?

Available on InboundDetourConfig, provided by the InboundDetourConfigPatterns extension

A variant of when that fallback to returning null