LimitFallback class abstract

Available extensions
Annotations
  • @freezed

Constructors

LimitFallback({int? afterBytes, int? bytesPerSec, int? burstBytesPerSec})
const
factory
LimitFallback.fromJson(Object? json)
factory

Properties

afterBytes int?
no setterinherited
burstBytesPerSec int?
no setterinherited
bytesPerSec int?
no setterinherited
copyWith → $LimitFallbackCopyWith<LimitFallback>
Create a copy of LimitFallback with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_LimitFallback value)) → TResult

Available on LimitFallback, provided by the LimitFallbackPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_LimitFallback value)?) → TResult?

Available on LimitFallback, provided by the LimitFallbackPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_LimitFallback value)?, {required TResult orElse()}) → TResult

Available on LimitFallback, provided by the LimitFallbackPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int? afterBytes, int? bytesPerSec, int? burstBytesPerSec)?, {required TResult orElse()}) → TResult

Available on LimitFallback, provided by the LimitFallbackPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int? afterBytes, int? bytesPerSec, int? burstBytesPerSec)) → TResult

Available on LimitFallback, provided by the LimitFallbackPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int? afterBytes, int? bytesPerSec, int? burstBytesPerSec)?) → TResult?

Available on LimitFallback, provided by the LimitFallbackPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited