LogConfigPatterns extension

Adds pattern-matching-related methods to LogConfig.

on

Methods

map<TResult extends Object?>(TResult $default(_LogConfig value)) → TResult

Available on LogConfig, provided by the LogConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_LogConfig value)?) → TResult?

Available on LogConfig, provided by the LogConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_LogConfig value)?, {required TResult orElse()}) → TResult

Available on LogConfig, provided by the LogConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? access, String? error, LogLevel? loglevel, bool? dnsLog, String? maskAddress)?, {required TResult orElse()}) → TResult

Available on LogConfig, provided by the LogConfigPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String? access, String? error, LogLevel? loglevel, bool? dnsLog, String? maskAddress)) → TResult

Available on LogConfig, provided by the LogConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? access, String? error, LogLevel? loglevel, bool? dnsLog, String? maskAddress)?) → TResult?

Available on LogConfig, provided by the LogConfigPatterns extension

A variant of when that fallback to returning null