LoopbackConfigPatterns extension

Adds pattern-matching-related methods to LoopbackConfig.

on

Methods

map<TResult extends Object?>(TResult $default(_LoopbackConfig value)) → TResult

Available on LoopbackConfig, provided by the LoopbackConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_LoopbackConfig value)?) → TResult?

Available on LoopbackConfig, provided by the LoopbackConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_LoopbackConfig value)?, {required TResult orElse()}) → TResult

Available on LoopbackConfig, provided by the LoopbackConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? inboundTag)?, {required TResult orElse()}) → TResult

Available on LoopbackConfig, provided by the LoopbackConfigPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String? inboundTag)) → TResult

Available on LoopbackConfig, provided by the LoopbackConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? inboundTag)?) → TResult?

Available on LoopbackConfig, provided by the LoopbackConfigPatterns extension

A variant of when that fallback to returning null