Masquerade class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
Properties
- content → String?
-
no setterinherited
-
copyWith
→ $MasqueradeCopyWith<
Masquerade> -
Create a copy of Masquerade
with the given fields replaced by the non-null parameter values.
no setterinherited
- dir → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> ? -
no setterinherited
- insecure → bool?
-
no setterinherited
- rewriteHost → bool?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int?
-
no setterinherited
- type → String?
-
no setterinherited
- url → String?
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_Masquerade value)) → TResult -
Available on Masquerade, provided by the MasqueradePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_Masquerade value)?) → TResult? -
Available on Masquerade, provided by the MasqueradePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_Masquerade value)?, {required TResult orElse()}) → TResult -
Available on Masquerade, provided by the MasqueradePatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? type, String? dir, String? url, bool? rewriteHost, bool? insecure, String? content, Map< String, String> ? headers, int? statusCode)?, {required TResult orElse()}) → TResult -
Available on Masquerade, provided by the MasqueradePatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? type, String? dir, String? url, bool? rewriteHost, bool? insecure, String? content, Map< String, String> ? headers, int? statusCode)) → TResult -
Available on Masquerade, provided by the MasqueradePatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? type, String? dir, String? url, bool? rewriteHost, bool? insecure, String? content, Map< String, String> ? headers, int? statusCode)?) → TResult? -
Available on Masquerade, provided by the MasqueradePatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited