MasqueradePatterns extension

Adds pattern-matching-related methods to Masquerade.

on

Methods

map<TResult extends Object?>(TResult $default(_Masquerade value)) → TResult

Available on Masquerade, provided by the MasqueradePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Masquerade value)?) → TResult?

Available on Masquerade, provided by the MasqueradePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Masquerade value)?, {required TResult orElse()}) → TResult

Available on Masquerade, provided by the MasqueradePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? type, String? dir, String? url, bool? rewriteHost, bool? insecure, String? content, Map<String, String>? headers, int? statusCode)?, {required TResult orElse()}) → TResult

Available on Masquerade, provided by the MasqueradePatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String? type, String? dir, String? url, bool? rewriteHost, bool? insecure, String? content, Map<String, String>? headers, int? statusCode)) → TResult

Available on Masquerade, provided by the MasqueradePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? type, String? dir, String? url, bool? rewriteHost, bool? insecure, String? content, Map<String, String>? headers, int? statusCode)?) → TResult?

Available on Masquerade, provided by the MasqueradePatterns extension

A variant of when that fallback to returning null