MetricsConfig class abstract

Available extensions
Annotations
  • @freezed

Constructors

MetricsConfig({String? tag, String? listen})
const
factory
MetricsConfig.fromJson(Object? json)
factory
MetricsConfig.listen(String listen, {String? tag})
factory
MetricsConfig.tag(String tag, {String? listen})
factory

Properties

copyWith → $MetricsConfigCopyWith<MetricsConfig>
Create a copy of MetricsConfig with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
listen String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_MetricsConfig value)) → TResult

Available on MetricsConfig, provided by the MetricsConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_MetricsConfig value)?) → TResult?

Available on MetricsConfig, provided by the MetricsConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_MetricsConfig value)?, {required TResult orElse()}) → TResult

Available on MetricsConfig, provided by the MetricsConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? tag, String? listen)?, {required TResult orElse()}) → TResult

Available on MetricsConfig, provided by the MetricsConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? tag, String? listen)) → TResult

Available on MetricsConfig, provided by the MetricsConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? tag, String? listen)?) → TResult?

Available on MetricsConfig, provided by the MetricsConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited