MuxConfig class abstract

Available extensions
Annotations
  • @freezed

Constructors

MuxConfig({bool? enabled, int? concurrency, int? xudpConcurrency, String? xudpProxyUDP443})
const
factory
MuxConfig.fromJson(Object? json)
factory

Properties

concurrency int?
no setterinherited
copyWith → $MuxConfigCopyWith<MuxConfig>
Create a copy of MuxConfig with the given fields replaced by the non-null parameter values.
no setterinherited
enabled bool?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
xudpConcurrency int?
no setterinherited
xudpProxyUDP443 String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_MuxConfig value)) → TResult

Available on MuxConfig, provided by the MuxConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_MuxConfig value)?) → TResult?

Available on MuxConfig, provided by the MuxConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_MuxConfig value)?, {required TResult orElse()}) → TResult

Available on MuxConfig, provided by the MuxConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(bool? enabled, int? concurrency, int? xudpConcurrency, String? xudpProxyUDP443)?, {required TResult orElse()}) → TResult

Available on MuxConfig, provided by the MuxConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(bool? enabled, int? concurrency, int? xudpConcurrency, String? xudpProxyUDP443)) → TResult

Available on MuxConfig, provided by the MuxConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(bool? enabled, int? concurrency, int? xudpConcurrency, String? xudpProxyUDP443)?) → TResult?

Available on MuxConfig, provided by the MuxConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited