NameServerConfig class abstract

Available extensions
Annotations
  • @freezed

Constructors

NameServerConfig({required XrayAddress address, XrayAddress? clientIp, int? port, bool? skipFallback, XrayStringList? domains, XrayStringList? expectedIPs, XrayStringList? expectIPs, DnsQueryStrategy? queryStrategy, String? tag, int? timeoutMs, bool? disableCache, bool? serveStale, int? serveExpiredTTL, bool? finalQuery, XrayStringList? unexpectedIPs, bool? simplified})
const
factory
NameServerConfig.fromJson(Object? json)
factory
NameServerConfig.simple(String address)
factory

Properties

address XrayAddress
no setterinherited
clientIp XrayAddress?
no setterinherited
copyWith → $NameServerConfigCopyWith<NameServerConfig>
Create a copy of NameServerConfig with the given fields replaced by the non-null parameter values.
no setterinherited
disableCache bool?
no setterinherited
domains XrayStringList?
no setterinherited
expectedIPs XrayStringList?
no setterinherited
expectIPs XrayStringList?
no setterinherited
finalQuery bool?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
port int?
no setterinherited
queryStrategy DnsQueryStrategy?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serveExpiredTTL int?
no setterinherited
serveStale bool?
no setterinherited
simplified bool?
no setterinherited
skipFallback bool?
no setterinherited
tag String?
no setterinherited
timeoutMs int?
no setterinherited
unexpectedIPs XrayStringList?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_NameServerConfig value)) → TResult

Available on NameServerConfig, provided by the NameServerConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_NameServerConfig value)?) → TResult?

Available on NameServerConfig, provided by the NameServerConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_NameServerConfig value)?, {required TResult orElse()}) → TResult

Available on NameServerConfig, provided by the NameServerConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(XrayAddress address, XrayAddress? clientIp, int? port, bool? skipFallback, XrayStringList? domains, XrayStringList? expectedIPs, XrayStringList? expectIPs, DnsQueryStrategy? queryStrategy, String? tag, int? timeoutMs, bool? disableCache, bool? serveStale, int? serveExpiredTTL, bool? finalQuery, XrayStringList? unexpectedIPs, bool? simplified)?, {required TResult orElse()}) → TResult

Available on NameServerConfig, provided by the NameServerConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(XrayAddress address, XrayAddress? clientIp, int? port, bool? skipFallback, XrayStringList? domains, XrayStringList? expectedIPs, XrayStringList? expectIPs, DnsQueryStrategy? queryStrategy, String? tag, int? timeoutMs, bool? disableCache, bool? serveStale, int? serveExpiredTTL, bool? finalQuery, XrayStringList? unexpectedIPs, bool? simplified)) → TResult

Available on NameServerConfig, provided by the NameServerConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(XrayAddress address, XrayAddress? clientIp, int? port, bool? skipFallback, XrayStringList? domains, XrayStringList? expectedIPs, XrayStringList? expectIPs, DnsQueryStrategy? queryStrategy, String? tag, int? timeoutMs, bool? disableCache, bool? serveStale, int? serveExpiredTTL, bool? finalQuery, XrayStringList? unexpectedIPs, bool? simplified)?) → TResult?

Available on NameServerConfig, provided by the NameServerConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited