Noise class abstract

Available extensions
Annotations
  • @freezed

Constructors

Noise({String? type, String? packet, XrayInt32Range? delay, String? applyTo})
const
factory
Noise.fromJson(Object? json)
factory

Properties

applyTo String?
no setterinherited
copyWith → $NoiseCopyWith<Noise>
Create a copy of Noise with the given fields replaced by the non-null parameter values.
no setterinherited
delay XrayInt32Range?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
packet String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Noise value)) → TResult

Available on Noise, provided by the NoisePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Noise value)?) → TResult?

Available on Noise, provided by the NoisePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Noise value)?, {required TResult orElse()}) → TResult

Available on Noise, provided by the NoisePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? type, String? packet, XrayInt32Range? delay, String? applyTo)?, {required TResult orElse()}) → TResult

Available on Noise, provided by the NoisePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? type, String? packet, XrayInt32Range? delay, String? applyTo)) → TResult

Available on Noise, provided by the NoisePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? type, String? packet, XrayInt32Range? delay, String? applyTo)?) → TResult?

Available on Noise, provided by the NoisePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited