NoiseItem class abstract

Available extensions
Annotations
  • @freezed

Constructors

NoiseItem({XrayInt32Range? rand, XrayInt32Range? randRange, String? type, Object? packet, XrayInt32Range? delay})
const
factory
NoiseItem.fromJson(Object? json)
factory

Properties

copyWith → $NoiseItemCopyWith<NoiseItem>
Create a copy of NoiseItem with the given fields replaced by the non-null parameter values.
no setterinherited
delay XrayInt32Range?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
packet Object?
no setterinherited
rand XrayInt32Range?
no setterinherited
randRange XrayInt32Range?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_NoiseItem value)) → TResult

Available on NoiseItem, provided by the NoiseItemPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_NoiseItem value)?) → TResult?

Available on NoiseItem, provided by the NoiseItemPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_NoiseItem value)?, {required TResult orElse()}) → TResult

Available on NoiseItem, provided by the NoiseItemPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(XrayInt32Range? rand, XrayInt32Range? randRange, String? type, Object? packet, XrayInt32Range? delay)?, {required TResult orElse()}) → TResult

Available on NoiseItem, provided by the NoiseItemPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(XrayInt32Range? rand, XrayInt32Range? randRange, String? type, Object? packet, XrayInt32Range? delay)) → TResult

Available on NoiseItem, provided by the NoiseItemPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(XrayInt32Range? rand, XrayInt32Range? randRange, String? type, Object? packet, XrayInt32Range? delay)?) → TResult?

Available on NoiseItem, provided by the NoiseItemPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited