ObservatoryConfig class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
ObservatoryConfig({List<
String> ? subjectSelector, String? probeURL, XrayDuration? probeInterval, bool? enableConcurrency}) -
constfactory
- ObservatoryConfig.fromJson(Object? json)
-
factory
Properties
-
copyWith
→ $ObservatoryConfigCopyWith<
ObservatoryConfig> -
Create a copy of ObservatoryConfig
with the given fields replaced by the non-null parameter values.
no setterinherited
- enableConcurrency → bool?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- probeInterval → XrayDuration?
-
no setterinherited
- probeURL → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subjectSelector
→ List<
String> ? -
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_ObservatoryConfig value)) → TResult -
Available on ObservatoryConfig, provided by the ObservatoryConfigPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_ObservatoryConfig value)?) → TResult? -
Available on ObservatoryConfig, provided by the ObservatoryConfigPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_ObservatoryConfig value)?, {required TResult orElse()}) → TResult -
Available on ObservatoryConfig, provided by the ObservatoryConfigPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(List< String> ? subjectSelector, String? probeURL, XrayDuration? probeInterval, bool? enableConcurrency)?, {required TResult orElse()}) → TResult -
Available on ObservatoryConfig, provided by the ObservatoryConfigPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(List< String> ? subjectSelector, String? probeURL, XrayDuration? probeInterval, bool? enableConcurrency)) → TResult -
Available on ObservatoryConfig, provided by the ObservatoryConfigPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(List< String> ? subjectSelector, String? probeURL, XrayDuration? probeInterval, bool? enableConcurrency)?) → TResult? -
Available on ObservatoryConfig, provided by the ObservatoryConfigPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited