OutboundDetourConfig class abstract

Available extensions
Annotations
  • @freezed

Constructors

OutboundDetourConfig({required String protocol, String? sendThrough, String? tag, XrayOutboundSettings? settings, StreamConfig? streamSettings, ProxyConfig? proxySettings, MuxConfig? mux, XrayTargetStrategy? targetStrategy})
const
factory
OutboundDetourConfig.block({String? tag, BlackholeConfig? settings})
factory
OutboundDetourConfig.direct({String? tag, String? sendThrough, FreedomConfig? settings, StreamConfig? streamSettings, ProxyConfig? proxySettings, MuxConfig? mux, XrayTargetStrategy? targetStrategy})
factory
OutboundDetourConfig.dns({required DNSOutboundConfig settings, String? tag, String? sendThrough, StreamConfig? streamSettings, ProxyConfig? proxySettings, MuxConfig? mux, XrayTargetStrategy? targetStrategy})
factory
OutboundDetourConfig.fromJson(Object? json)
factory
OutboundDetourConfig.fromProtocol({required XrayOutboundProtocol protocol, String? sendThrough, String? tag, XrayOutboundSettings? settings, StreamConfig? streamSettings, ProxyConfig? proxySettings, MuxConfig? mux, XrayTargetStrategy? targetStrategy})
factory
OutboundDetourConfig.http({required HTTPClientConfig settings, String? tag, String? sendThrough, StreamConfig? streamSettings, ProxyConfig? proxySettings, MuxConfig? mux, XrayTargetStrategy? targetStrategy})
factory
OutboundDetourConfig.hysteria({required HysteriaClientConfig settings, String? tag, String? sendThrough, StreamConfig? streamSettings, ProxyConfig? proxySettings, MuxConfig? mux, XrayTargetStrategy? targetStrategy})
factory
OutboundDetourConfig.shadowsocks({required ShadowsocksClientConfig settings, String? tag, String? sendThrough, StreamConfig? streamSettings, ProxyConfig? proxySettings, MuxConfig? mux, XrayTargetStrategy? targetStrategy})
factory
OutboundDetourConfig.socks({required SocksClientConfig settings, String? tag, String? sendThrough, StreamConfig? streamSettings, ProxyConfig? proxySettings, MuxConfig? mux, XrayTargetStrategy? targetStrategy})
factory
OutboundDetourConfig.trojan({required TrojanClientConfig settings, String? tag, String? sendThrough, StreamConfig? streamSettings, ProxyConfig? proxySettings, MuxConfig? mux, XrayTargetStrategy? targetStrategy})
factory
OutboundDetourConfig.vless({required VLessOutboundConfig settings, String? tag, String? sendThrough, StreamConfig? streamSettings, ProxyConfig? proxySettings, MuxConfig? mux, XrayTargetStrategy? targetStrategy})
factory
OutboundDetourConfig.vmess({required VMessOutboundConfig settings, String? tag, String? sendThrough, StreamConfig? streamSettings, ProxyConfig? proxySettings, MuxConfig? mux, XrayTargetStrategy? targetStrategy})
factory
OutboundDetourConfig.wireguard({required WireGuardConfig settings, String? tag, String? sendThrough, StreamConfig? streamSettings, ProxyConfig? proxySettings, MuxConfig? mux, XrayTargetStrategy? targetStrategy})
factory

Properties

copyWith → $OutboundDetourConfigCopyWith<OutboundDetourConfig>
Create a copy of OutboundDetourConfig with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
mux MuxConfig?
no setterinherited
protocol String
no setterinherited
proxySettings ProxyConfig?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendThrough String?
no setterinherited
settings XrayOutboundSettings?
no setterinherited
streamSettings StreamConfig?
no setterinherited
tag String?
no setterinherited
targetStrategy XrayTargetStrategy?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_OutboundDetourConfig value)) → TResult

Available on OutboundDetourConfig, provided by the OutboundDetourConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_OutboundDetourConfig value)?) → TResult?

Available on OutboundDetourConfig, provided by the OutboundDetourConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_OutboundDetourConfig value)?, {required TResult orElse()}) → TResult

Available on OutboundDetourConfig, provided by the OutboundDetourConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String protocol, String? sendThrough, String? tag, XrayOutboundSettings? settings, StreamConfig? streamSettings, ProxyConfig? proxySettings, MuxConfig? mux, XrayTargetStrategy? targetStrategy)?, {required TResult orElse()}) → TResult

Available on OutboundDetourConfig, provided by the OutboundDetourConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String protocol, String? sendThrough, String? tag, XrayOutboundSettings? settings, StreamConfig? streamSettings, ProxyConfig? proxySettings, MuxConfig? mux, XrayTargetStrategy? targetStrategy)) → TResult

Available on OutboundDetourConfig, provided by the OutboundDetourConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String protocol, String? sendThrough, String? tag, XrayOutboundSettings? settings, StreamConfig? streamSettings, ProxyConfig? proxySettings, MuxConfig? mux, XrayTargetStrategy? targetStrategy)?) → TResult?

Available on OutboundDetourConfig, provided by the OutboundDetourConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited