OutboundDetourConfigPatterns extension

Adds pattern-matching-related methods to OutboundDetourConfig.

on

Methods

map<TResult extends Object?>(TResult $default(_OutboundDetourConfig value)) → TResult

Available on OutboundDetourConfig, provided by the OutboundDetourConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_OutboundDetourConfig value)?) → TResult?

Available on OutboundDetourConfig, provided by the OutboundDetourConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_OutboundDetourConfig value)?, {required TResult orElse()}) → TResult

Available on OutboundDetourConfig, provided by the OutboundDetourConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String protocol, String? sendThrough, String? tag, XrayOutboundSettings? settings, StreamConfig? streamSettings, ProxyConfig? proxySettings, MuxConfig? mux, XrayTargetStrategy? targetStrategy)?, {required TResult orElse()}) → TResult

Available on OutboundDetourConfig, provided by the OutboundDetourConfigPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String protocol, String? sendThrough, String? tag, XrayOutboundSettings? settings, StreamConfig? streamSettings, ProxyConfig? proxySettings, MuxConfig? mux, XrayTargetStrategy? targetStrategy)) → TResult

Available on OutboundDetourConfig, provided by the OutboundDetourConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String protocol, String? sendThrough, String? tag, XrayOutboundSettings? settings, StreamConfig? streamSettings, ProxyConfig? proxySettings, MuxConfig? mux, XrayTargetStrategy? targetStrategy)?) → TResult?

Available on OutboundDetourConfig, provided by the OutboundDetourConfigPatterns extension

A variant of when that fallback to returning null