Policy class abstract

Available extensions
Annotations
  • @freezed

Constructors

Policy({int? handshake, @JsonKey.new(name: 'connIdle') int? connectionIdle, int? uplinkOnly, int? downlinkOnly, bool? statsUserUplink, bool? statsUserDownlink, bool? statsUserOnline, int? bufferSize})
const
factory
Policy.fromJson(Object? json)
factory

Properties

bufferSize int?
no setterinherited
connectionIdle int?
no setterinherited
copyWith → $PolicyCopyWith<Policy>
Create a copy of Policy with the given fields replaced by the non-null parameter values.
no setterinherited
downlinkOnly int?
no setterinherited
handshake int?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
no setterinherited
statsUserOnline bool?
no setterinherited
no setterinherited
uplinkOnly int?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Policy value)) → TResult

Available on Policy, provided by the PolicyPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Policy value)?) → TResult?

Available on Policy, provided by the PolicyPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Policy value)?, {required TResult orElse()}) → TResult

Available on Policy, provided by the PolicyPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int? handshake, int? connectionIdle, int? uplinkOnly, int? downlinkOnly, bool? statsUserUplink, bool? statsUserDownlink, bool? statsUserOnline, int? bufferSize)?, {required TResult orElse()}) → TResult

Available on Policy, provided by the PolicyPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int? handshake, int? connectionIdle, int? uplinkOnly, int? downlinkOnly, bool? statsUserUplink, bool? statsUserDownlink, bool? statsUserOnline, int? bufferSize)) → TResult

Available on Policy, provided by the PolicyPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int? handshake, int? connectionIdle, int? uplinkOnly, int? downlinkOnly, bool? statsUserUplink, bool? statsUserDownlink, bool? statsUserOnline, int? bufferSize)?) → TResult?

Available on Policy, provided by the PolicyPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited