PolicyConfigPatterns extension

Adds pattern-matching-related methods to PolicyConfig.

on

Methods

map<TResult extends Object?>(TResult $default(_PolicyConfig value)) → TResult

Available on PolicyConfig, provided by the PolicyConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_PolicyConfig value)?) → TResult?

Available on PolicyConfig, provided by the PolicyConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_PolicyConfig value)?, {required TResult orElse()}) → TResult

Available on PolicyConfig, provided by the PolicyConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(Map<int, Policy>? levels, SystemPolicy? system)?, {required TResult orElse()}) → TResult

Available on PolicyConfig, provided by the PolicyConfigPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(Map<int, Policy>? levels, SystemPolicy? system)) → TResult

Available on PolicyConfig, provided by the PolicyConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(Map<int, Policy>? levels, SystemPolicy? system)?) → TResult?

Available on PolicyConfig, provided by the PolicyConfigPatterns extension

A variant of when that fallback to returning null