PolicyPatterns extension

Adds pattern-matching-related methods to Policy.

on

Methods

map<TResult extends Object?>(TResult $default(_Policy value)) → TResult

Available on Policy, provided by the PolicyPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Policy value)?) → TResult?

Available on Policy, provided by the PolicyPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Policy value)?, {required TResult orElse()}) → TResult

Available on Policy, provided by the PolicyPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int? handshake, int? connectionIdle, int? uplinkOnly, int? downlinkOnly, bool? statsUserUplink, bool? statsUserDownlink, bool? statsUserOnline, int? bufferSize)?, {required TResult orElse()}) → TResult

Available on Policy, provided by the PolicyPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(int? handshake, int? connectionIdle, int? uplinkOnly, int? downlinkOnly, bool? statsUserUplink, bool? statsUserDownlink, bool? statsUserOnline, int? bufferSize)) → TResult

Available on Policy, provided by the PolicyPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int? handshake, int? connectionIdle, int? uplinkOnly, int? downlinkOnly, bool? statsUserUplink, bool? statsUserDownlink, bool? statsUserOnline, int? bufferSize)?) → TResult?

Available on Policy, provided by the PolicyPatterns extension

A variant of when that fallback to returning null