PortalConfig class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- PortalConfig({String? tag, String? domain})
-
constfactory
- PortalConfig.fromJson(Object? json)
-
factory
Properties
-
copyWith
→ $PortalConfigCopyWith<
PortalConfig> -
Create a copy of PortalConfig
with the given fields replaced by the non-null parameter values.
no setterinherited
- domain → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String?
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_PortalConfig value)) → TResult -
Available on PortalConfig, provided by the PortalConfigPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_PortalConfig value)?) → TResult? -
Available on PortalConfig, provided by the PortalConfigPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_PortalConfig value)?, {required TResult orElse()}) → TResult -
Available on PortalConfig, provided by the PortalConfigPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? tag, String? domain)?, {required TResult orElse()}) → TResult -
Available on PortalConfig, provided by the PortalConfigPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? tag, String? domain)) → TResult -
Available on PortalConfig, provided by the PortalConfigPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? tag, String? domain)?) → TResult? -
Available on PortalConfig, provided by the PortalConfigPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited