ProxyConfig class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- ProxyConfig({required String tag, bool? transportLayer})
-
constfactory
- ProxyConfig.fromJson(Object? json)
-
factory
Properties
-
copyWith
→ $ProxyConfigCopyWith<
ProxyConfig> -
Create a copy of ProxyConfig
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
no setterinherited
- transportLayer → bool?
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_ProxyConfig value)) → TResult -
Available on ProxyConfig, provided by the ProxyConfigPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_ProxyConfig value)?) → TResult? -
Available on ProxyConfig, provided by the ProxyConfigPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_ProxyConfig value)?, {required TResult orElse()}) → TResult -
Available on ProxyConfig, provided by the ProxyConfigPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String tag, bool? transportLayer)?, {required TResult orElse()}) → TResult -
Available on ProxyConfig, provided by the ProxyConfigPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String tag, bool? transportLayer)) → TResult -
Available on ProxyConfig, provided by the ProxyConfigPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String tag, bool? transportLayer)?) → TResult? -
Available on ProxyConfig, provided by the ProxyConfigPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited