QuicParamsConfig class abstract

Available extensions
Annotations
  • @freezed

Constructors

QuicParamsConfig({String? congestion, bool? debug, String? bbrProfile, Bandwidth? brutalUp, Bandwidth? brutalDown, UdpHop? udpHop, int? initStreamReceiveWindow, int? maxStreamReceiveWindow, int? initConnectionReceiveWindow, int? maxConnectionReceiveWindow, int? maxIdleTimeout, int? keepAlivePeriod, bool? disablePathMTUDiscovery, int? maxIncomingStreams})
const
factory
QuicParamsConfig.fromJson(Object? json)
factory

Properties

bbrProfile String?
no setterinherited
brutalDown Bandwidth?
no setterinherited
brutalUp Bandwidth?
no setterinherited
congestion String?
no setterinherited
copyWith → $QuicParamsConfigCopyWith<QuicParamsConfig>
Create a copy of QuicParamsConfig with the given fields replaced by the non-null parameter values.
no setterinherited
debug bool?
no setterinherited
disablePathMTUDiscovery bool?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
initConnectionReceiveWindow int?
no setterinherited
initStreamReceiveWindow int?
no setterinherited
keepAlivePeriod int?
no setterinherited
maxConnectionReceiveWindow int?
no setterinherited
maxIdleTimeout int?
no setterinherited
maxIncomingStreams int?
no setterinherited
maxStreamReceiveWindow int?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
udpHop UdpHop?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_QuicParamsConfig value)) → TResult

Available on QuicParamsConfig, provided by the QuicParamsConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_QuicParamsConfig value)?) → TResult?

Available on QuicParamsConfig, provided by the QuicParamsConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_QuicParamsConfig value)?, {required TResult orElse()}) → TResult

Available on QuicParamsConfig, provided by the QuicParamsConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? congestion, bool? debug, String? bbrProfile, Bandwidth? brutalUp, Bandwidth? brutalDown, UdpHop? udpHop, int? initStreamReceiveWindow, int? maxStreamReceiveWindow, int? initConnectionReceiveWindow, int? maxConnectionReceiveWindow, int? maxIdleTimeout, int? keepAlivePeriod, bool? disablePathMTUDiscovery, int? maxIncomingStreams)?, {required TResult orElse()}) → TResult

Available on QuicParamsConfig, provided by the QuicParamsConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? congestion, bool? debug, String? bbrProfile, Bandwidth? brutalUp, Bandwidth? brutalDown, UdpHop? udpHop, int? initStreamReceiveWindow, int? maxStreamReceiveWindow, int? initConnectionReceiveWindow, int? maxConnectionReceiveWindow, int? maxIdleTimeout, int? keepAlivePeriod, bool? disablePathMTUDiscovery, int? maxIncomingStreams)) → TResult

Available on QuicParamsConfig, provided by the QuicParamsConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? congestion, bool? debug, String? bbrProfile, Bandwidth? brutalUp, Bandwidth? brutalDown, UdpHop? udpHop, int? initStreamReceiveWindow, int? maxStreamReceiveWindow, int? initConnectionReceiveWindow, int? maxConnectionReceiveWindow, int? maxIdleTimeout, int? keepAlivePeriod, bool? disablePathMTUDiscovery, int? maxIncomingStreams)?) → TResult?

Available on QuicParamsConfig, provided by the QuicParamsConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited