QuicParamsConfigPatterns extension

Adds pattern-matching-related methods to QuicParamsConfig.

on

Methods

map<TResult extends Object?>(TResult $default(_QuicParamsConfig value)) → TResult

Available on QuicParamsConfig, provided by the QuicParamsConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_QuicParamsConfig value)?) → TResult?

Available on QuicParamsConfig, provided by the QuicParamsConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_QuicParamsConfig value)?, {required TResult orElse()}) → TResult

Available on QuicParamsConfig, provided by the QuicParamsConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? congestion, bool? debug, String? bbrProfile, Bandwidth? brutalUp, Bandwidth? brutalDown, UdpHop? udpHop, int? initStreamReceiveWindow, int? maxStreamReceiveWindow, int? initConnectionReceiveWindow, int? maxConnectionReceiveWindow, int? maxIdleTimeout, int? keepAlivePeriod, bool? disablePathMTUDiscovery, int? maxIncomingStreams)?, {required TResult orElse()}) → TResult

Available on QuicParamsConfig, provided by the QuicParamsConfigPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String? congestion, bool? debug, String? bbrProfile, Bandwidth? brutalUp, Bandwidth? brutalDown, UdpHop? udpHop, int? initStreamReceiveWindow, int? maxStreamReceiveWindow, int? initConnectionReceiveWindow, int? maxConnectionReceiveWindow, int? maxIdleTimeout, int? keepAlivePeriod, bool? disablePathMTUDiscovery, int? maxIncomingStreams)) → TResult

Available on QuicParamsConfig, provided by the QuicParamsConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? congestion, bool? debug, String? bbrProfile, Bandwidth? brutalUp, Bandwidth? brutalDown, UdpHop? udpHop, int? initStreamReceiveWindow, int? maxStreamReceiveWindow, int? initConnectionReceiveWindow, int? maxConnectionReceiveWindow, int? maxIdleTimeout, int? keepAlivePeriod, bool? disablePathMTUDiscovery, int? maxIncomingStreams)?) → TResult?

Available on QuicParamsConfig, provided by the QuicParamsConfigPatterns extension

A variant of when that fallback to returning null