REALITYConfig class abstract

Available extensions
Annotations
  • @freezed

Constructors

REALITYConfig({String? masterKeyLog, bool? show, Object? target, Object? dest, String? type, int? xver, List<String>? serverNames, String? privateKey, String? minClientVer, String? maxClientVer, int? maxTimeDiff, List<String>? shortIds, String? mldsa65Seed, LimitFallback? limitFallbackUpload, LimitFallback? limitFallbackDownload, String? fingerprint, String? serverName, String? password, String? publicKey, String? shortId, String? mldsa65Verify, String? spiderX})
const
factory
REALITYConfig.client({String? fingerprint, String? serverName, required String publicKey, String? shortId, String? spiderX, String? mldsa65Verify})
factory
REALITYConfig.fromJson(Object? json)
factory
REALITYConfig.server({required Object target, String? type, int? xver, required List<String> serverNames, required String privateKey, required List<String> shortIds, String? minClientVer, String? maxClientVer, int? maxTimeDiff, String? mldsa65Seed, LimitFallback? limitFallbackUpload, LimitFallback? limitFallbackDownload, String? masterKeyLog, bool? show})
factory

Properties

copyWith → $REALITYConfigCopyWith<REALITYConfig>
Create a copy of REALITYConfig with the given fields replaced by the non-null parameter values.
no setterinherited
dest Object?
no setterinherited
fingerprint String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
limitFallbackDownload LimitFallback?
no setterinherited
limitFallbackUpload LimitFallback?
no setterinherited
masterKeyLog String?
no setterinherited
maxClientVer String?
no setterinherited
maxTimeDiff int?
no setterinherited
minClientVer String?
no setterinherited
mldsa65Seed String?
no setterinherited
mldsa65Verify String?
no setterinherited
password String?
no setterinherited
privateKey String?
no setterinherited
publicKey String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverName String?
no setterinherited
serverNames List<String>?
no setterinherited
shortId String?
no setterinherited
shortIds List<String>?
no setterinherited
show bool?
no setterinherited
spiderX String?
no setterinherited
target Object?
no setterinherited
type String?
no setterinherited
xver int?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_REALITYConfig value)) → TResult

Available on REALITYConfig, provided by the REALITYConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_REALITYConfig value)?) → TResult?

Available on REALITYConfig, provided by the REALITYConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_REALITYConfig value)?, {required TResult orElse()}) → TResult

Available on REALITYConfig, provided by the REALITYConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? masterKeyLog, bool? show, Object? target, Object? dest, String? type, int? xver, List<String>? serverNames, String? privateKey, String? minClientVer, String? maxClientVer, int? maxTimeDiff, List<String>? shortIds, String? mldsa65Seed, LimitFallback? limitFallbackUpload, LimitFallback? limitFallbackDownload, String? fingerprint, String? serverName, String? password, String? publicKey, String? shortId, String? mldsa65Verify, String? spiderX)?, {required TResult orElse()}) → TResult

Available on REALITYConfig, provided by the REALITYConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? masterKeyLog, bool? show, Object? target, Object? dest, String? type, int? xver, List<String>? serverNames, String? privateKey, String? minClientVer, String? maxClientVer, int? maxTimeDiff, List<String>? shortIds, String? mldsa65Seed, LimitFallback? limitFallbackUpload, LimitFallback? limitFallbackDownload, String? fingerprint, String? serverName, String? password, String? publicKey, String? shortId, String? mldsa65Verify, String? spiderX)) → TResult

Available on REALITYConfig, provided by the REALITYConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? masterKeyLog, bool? show, Object? target, Object? dest, String? type, int? xver, List<String>? serverNames, String? privateKey, String? minClientVer, String? maxClientVer, int? maxTimeDiff, List<String>? shortIds, String? mldsa65Seed, LimitFallback? limitFallbackUpload, LimitFallback? limitFallbackDownload, String? fingerprint, String? serverName, String? password, String? publicKey, String? shortId, String? mldsa65Verify, String? spiderX)?) → TResult?

Available on REALITYConfig, provided by the REALITYConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited