Realm class abstract

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

Realm({String? url, List<String>? stunServers, TLSConfig? tlsConfig})
const
factory
Realm.fromJson(Object? json)
factory

Properties

copyWith → $RealmCopyWith<Realm>
Create a copy of Realm with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stunServers List<String>?
no setterinherited
tlsConfig TLSConfig?
no setterinherited
url String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Realm value)) → TResult

Available on Realm, provided by the RealmPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Realm value)?) → TResult?

Available on Realm, provided by the RealmPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Realm value)?, {required TResult orElse()}) → TResult

Available on Realm, provided by the RealmPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? url, List<String>? stunServers, TLSConfig? tlsConfig)?, {required TResult orElse()}) → TResult

Available on Realm, provided by the RealmPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? url, List<String>? stunServers, TLSConfig? tlsConfig)) → TResult

Available on Realm, provided by the RealmPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? url, List<String>? stunServers, TLSConfig? tlsConfig)?) → TResult?

Available on Realm, provided by the RealmPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited