ReverseConfig class abstract

Available extensions
Annotations
  • @freezed

Constructors

ReverseConfig({List<BridgeConfig>? bridges, List<PortalConfig>? portals})
const
factory
ReverseConfig.fromJson(Object? json)
factory

Properties

bridges List<BridgeConfig>?
no setterinherited
copyWith → $ReverseConfigCopyWith<ReverseConfig>
Create a copy of ReverseConfig with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
portals List<PortalConfig>?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ReverseConfig value)) → TResult

Available on ReverseConfig, provided by the ReverseConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ReverseConfig value)?) → TResult?

Available on ReverseConfig, provided by the ReverseConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ReverseConfig value)?, {required TResult orElse()}) → TResult

Available on ReverseConfig, provided by the ReverseConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(List<BridgeConfig>? bridges, List<PortalConfig>? portals)?, {required TResult orElse()}) → TResult

Available on ReverseConfig, provided by the ReverseConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(List<BridgeConfig>? bridges, List<PortalConfig>? portals)) → TResult

Available on ReverseConfig, provided by the ReverseConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(List<BridgeConfig>? bridges, List<PortalConfig>? portals)?) → TResult?

Available on ReverseConfig, provided by the ReverseConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited