toString method

  1. @override
String toString()
inherited

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  return 'RouterRule(ruleTag: $ruleTag, outboundTag: $outboundTag, balancerTag: $balancerTag, domain: $domain, domains: $domains, ip: $ip, port: $port, network: $network, sourceIP: $sourceIP, source: $source, sourcePort: $sourcePort, user: $user, vlessRoute: $vlessRoute, inboundTag: $inboundTag, protocols: $protocols, attributes: $attributes, localIP: $localIP, localPort: $localPort, process: $process, webhook: $webhook)';
}