ShadowsocksServerConfig class abstract

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

ShadowsocksServerConfig({@JsonKey.new(name: 'method') String? cipher, String? password, int? level, String? email, @JsonKey.new(name: 'clients') List<ShadowsocksUserConfig>? users, @JsonKey.new(name: 'network') XrayNetworkList? networkList})
const
factory
ShadowsocksServerConfig.fromJson(Object? json)
factory
ShadowsocksServerConfig.single({required String cipher, required String password, int? level, String? email, XrayNetworkList? networkList})
factory

Properties

cipher String?
no setterinherited
copyWith → $ShadowsocksServerConfigCopyWith<ShadowsocksServerConfig>
Create a copy of ShadowsocksServerConfig with the given fields replaced by the non-null parameter values.
no setterinherited
email String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
level int?
no setterinherited
networkList XrayNetworkList?
no setterinherited
password String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
users List<ShadowsocksUserConfig>?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ShadowsocksServerConfig value)) → TResult

Available on ShadowsocksServerConfig, provided by the ShadowsocksServerConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ShadowsocksServerConfig value)?) → TResult?

Available on ShadowsocksServerConfig, provided by the ShadowsocksServerConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ShadowsocksServerConfig value)?, {required TResult orElse()}) → TResult

Available on ShadowsocksServerConfig, provided by the ShadowsocksServerConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? cipher, String? password, int? level, String? email, List<ShadowsocksUserConfig>? users, XrayNetworkList? networkList)?, {required TResult orElse()}) → TResult

Available on ShadowsocksServerConfig, provided by the ShadowsocksServerConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? cipher, String? password, int? level, String? email, List<ShadowsocksUserConfig>? users, XrayNetworkList? networkList)) → TResult

Available on ShadowsocksServerConfig, provided by the ShadowsocksServerConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? cipher, String? password, int? level, String? email, List<ShadowsocksUserConfig>? users, XrayNetworkList? networkList)?) → TResult?

Available on ShadowsocksServerConfig, provided by the ShadowsocksServerConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited