ShadowsocksServerConfigPatterns extension

Adds pattern-matching-related methods to ShadowsocksServerConfig.

on

Methods

map<TResult extends Object?>(TResult $default(_ShadowsocksServerConfig value)) → TResult

Available on ShadowsocksServerConfig, provided by the ShadowsocksServerConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ShadowsocksServerConfig value)?) → TResult?

Available on ShadowsocksServerConfig, provided by the ShadowsocksServerConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ShadowsocksServerConfig value)?, {required TResult orElse()}) → TResult

Available on ShadowsocksServerConfig, provided by the ShadowsocksServerConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? cipher, String? password, int? level, String? email, List<ShadowsocksUserConfig>? users, XrayNetworkList? networkList)?, {required TResult orElse()}) → TResult

Available on ShadowsocksServerConfig, provided by the ShadowsocksServerConfigPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String? cipher, String? password, int? level, String? email, List<ShadowsocksUserConfig>? users, XrayNetworkList? networkList)) → TResult

Available on ShadowsocksServerConfig, provided by the ShadowsocksServerConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? cipher, String? password, int? level, String? email, List<ShadowsocksUserConfig>? users, XrayNetworkList? networkList)?) → TResult?

Available on ShadowsocksServerConfig, provided by the ShadowsocksServerConfigPatterns extension

A variant of when that fallback to returning null