ShadowsocksUserConfig class abstract

Available extensions
Annotations
  • @freezed

Constructors

ShadowsocksUserConfig({@JsonKey.new(name: 'method') String? cipher, required String password, int? level, String? email, XrayAddress? address, int? port})
const
factory
ShadowsocksUserConfig.fromJson(Object? json)
factory

Properties

address XrayAddress?
no setterinherited
cipher String?
no setterinherited
copyWith → $ShadowsocksUserConfigCopyWith<ShadowsocksUserConfig>
Create a copy of ShadowsocksUserConfig with the given fields replaced by the non-null parameter values.
no setterinherited
email String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
level int?
no setterinherited
password String
no setterinherited
port int?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ShadowsocksUserConfig value)) → TResult

Available on ShadowsocksUserConfig, provided by the ShadowsocksUserConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ShadowsocksUserConfig value)?) → TResult?

Available on ShadowsocksUserConfig, provided by the ShadowsocksUserConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ShadowsocksUserConfig value)?, {required TResult orElse()}) → TResult

Available on ShadowsocksUserConfig, provided by the ShadowsocksUserConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? cipher, String password, int? level, String? email, XrayAddress? address, int? port)?, {required TResult orElse()}) → TResult

Available on ShadowsocksUserConfig, provided by the ShadowsocksUserConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? cipher, String password, int? level, String? email, XrayAddress? address, int? port)) → TResult

Available on ShadowsocksUserConfig, provided by the ShadowsocksUserConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? cipher, String password, int? level, String? email, XrayAddress? address, int? port)?) → TResult?

Available on ShadowsocksUserConfig, provided by the ShadowsocksUserConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited