SniffingConfig class abstract

Available extensions
Annotations
  • @freezed

Constructors

SniffingConfig({bool? enabled, XrayStringList? destOverride, XrayStringList? domainsExcluded, XrayStringList? ipsExcluded, bool? metadataOnly, bool? routeOnly})
const
factory
SniffingConfig.fromJson(Object? json)
factory

Properties

copyWith → $SniffingConfigCopyWith<SniffingConfig>
Create a copy of SniffingConfig with the given fields replaced by the non-null parameter values.
no setterinherited
destOverride XrayStringList?
no setterinherited
domainsExcluded XrayStringList?
no setterinherited
enabled bool?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
ipsExcluded XrayStringList?
no setterinherited
metadataOnly bool?
no setterinherited
routeOnly bool?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_SniffingConfig value)) → TResult

Available on SniffingConfig, provided by the SniffingConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SniffingConfig value)?) → TResult?

Available on SniffingConfig, provided by the SniffingConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SniffingConfig value)?, {required TResult orElse()}) → TResult

Available on SniffingConfig, provided by the SniffingConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(bool? enabled, XrayStringList? destOverride, XrayStringList? domainsExcluded, XrayStringList? ipsExcluded, bool? metadataOnly, bool? routeOnly)?, {required TResult orElse()}) → TResult

Available on SniffingConfig, provided by the SniffingConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(bool? enabled, XrayStringList? destOverride, XrayStringList? domainsExcluded, XrayStringList? ipsExcluded, bool? metadataOnly, bool? routeOnly)) → TResult

Available on SniffingConfig, provided by the SniffingConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(bool? enabled, XrayStringList? destOverride, XrayStringList? domainsExcluded, XrayStringList? ipsExcluded, bool? metadataOnly, bool? routeOnly)?) → TResult?

Available on SniffingConfig, provided by the SniffingConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited