SocketConfig class abstract

Available extensions
Annotations
  • @freezed

Constructors

SocketConfig({int? mark, Object? tcpFastOpen, TProxyMode? tproxy, bool? acceptProxyProtocol, XrayTargetStrategy? domainStrategy, String? dialerProxy, int? tcpKeepAliveInterval, int? tcpKeepAliveIdle, String? tcpCongestion, int? tcpWindowClamp, int? tcpMaxSeg, bool? penetrate, int? tcpUserTimeout, bool? v6only, @JsonKey.new(name: 'interface') String? interfaceName, bool? tcpMptcp, List<CustomSockoptConfig>? customSockopt, AddressPortStrategy? addressPortStrategy, HappyEyeballsConfig? happyEyeballs, List<String>? trustedXForwardedFor})
const
factory
SocketConfig.fromJson(Object? json)
factory

Properties

acceptProxyProtocol bool?
no setterinherited
addressPortStrategy AddressPortStrategy?
no setterinherited
copyWith → $SocketConfigCopyWith<SocketConfig>
Create a copy of SocketConfig with the given fields replaced by the non-null parameter values.
no setterinherited
customSockopt List<CustomSockoptConfig>?
no setterinherited
dialerProxy String?
no setterinherited
domainStrategy XrayTargetStrategy?
no setterinherited
happyEyeballs HappyEyeballsConfig?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
interfaceName String?
no setterinherited
mark int?
no setterinherited
penetrate bool?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tcpCongestion String?
no setterinherited
tcpFastOpen Object?
no setterinherited
tcpKeepAliveIdle int?
no setterinherited
tcpKeepAliveInterval int?
no setterinherited
tcpMaxSeg int?
no setterinherited
tcpMptcp bool?
no setterinherited
tcpUserTimeout int?
no setterinherited
tcpWindowClamp int?
no setterinherited
tproxy TProxyMode?
no setterinherited
trustedXForwardedFor List<String>?
no setterinherited
v6only bool?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_SocketConfig value)) → TResult

Available on SocketConfig, provided by the SocketConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SocketConfig value)?) → TResult?

Available on SocketConfig, provided by the SocketConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SocketConfig value)?, {required TResult orElse()}) → TResult

Available on SocketConfig, provided by the SocketConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int? mark, Object? tcpFastOpen, TProxyMode? tproxy, bool? acceptProxyProtocol, XrayTargetStrategy? domainStrategy, String? dialerProxy, int? tcpKeepAliveInterval, int? tcpKeepAliveIdle, String? tcpCongestion, int? tcpWindowClamp, int? tcpMaxSeg, bool? penetrate, int? tcpUserTimeout, bool? v6only, String? interfaceName, bool? tcpMptcp, List<CustomSockoptConfig>? customSockopt, AddressPortStrategy? addressPortStrategy, HappyEyeballsConfig? happyEyeballs, List<String>? trustedXForwardedFor)?, {required TResult orElse()}) → TResult

Available on SocketConfig, provided by the SocketConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int? mark, Object? tcpFastOpen, TProxyMode? tproxy, bool? acceptProxyProtocol, XrayTargetStrategy? domainStrategy, String? dialerProxy, int? tcpKeepAliveInterval, int? tcpKeepAliveIdle, String? tcpCongestion, int? tcpWindowClamp, int? tcpMaxSeg, bool? penetrate, int? tcpUserTimeout, bool? v6only, String? interfaceName, bool? tcpMptcp, List<CustomSockoptConfig>? customSockopt, AddressPortStrategy? addressPortStrategy, HappyEyeballsConfig? happyEyeballs, List<String>? trustedXForwardedFor)) → TResult

Available on SocketConfig, provided by the SocketConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int? mark, Object? tcpFastOpen, TProxyMode? tproxy, bool? acceptProxyProtocol, XrayTargetStrategy? domainStrategy, String? dialerProxy, int? tcpKeepAliveInterval, int? tcpKeepAliveIdle, String? tcpCongestion, int? tcpWindowClamp, int? tcpMaxSeg, bool? penetrate, int? tcpUserTimeout, bool? v6only, String? interfaceName, bool? tcpMptcp, List<CustomSockoptConfig>? customSockopt, AddressPortStrategy? addressPortStrategy, HappyEyeballsConfig? happyEyeballs, List<String>? trustedXForwardedFor)?) → TResult?

Available on SocketConfig, provided by the SocketConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited