toString method

  1. @override
String toString()
inherited

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  return 'SocketConfig(mark: $mark, tcpFastOpen: $tcpFastOpen, tproxy: $tproxy, acceptProxyProtocol: $acceptProxyProtocol, domainStrategy: $domainStrategy, dialerProxy: $dialerProxy, tcpKeepAliveInterval: $tcpKeepAliveInterval, tcpKeepAliveIdle: $tcpKeepAliveIdle, tcpCongestion: $tcpCongestion, tcpWindowClamp: $tcpWindowClamp, tcpMaxSeg: $tcpMaxSeg, penetrate: $penetrate, tcpUserTimeout: $tcpUserTimeout, v6only: $v6only, interfaceName: $interfaceName, tcpMptcp: $tcpMptcp, customSockopt: $customSockopt, addressPortStrategy: $addressPortStrategy, happyEyeballs: $happyEyeballs, trustedXForwardedFor: $trustedXForwardedFor)';
}