SocksClientConfig class abstract

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

SocksClientConfig({XrayAddress? address, int? port, int? level, String? email, @JsonKey.new(name: 'user') String? username, @JsonKey.new(name: 'pass') String? password, List<SocksRemoteConfig>? servers})
const
factory
SocksClientConfig.fromJson(Object? json)
factory
SocksClientConfig.single({required XrayAddress address, required int port, int? level, String? email, String? username, String? password})
factory

Properties

address XrayAddress?
no setterinherited
copyWith → $SocksClientConfigCopyWith<SocksClientConfig>
Create a copy of SocksClientConfig with the given fields replaced by the non-null parameter values.
no setterinherited
email String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
level int?
no setterinherited
password String?
no setterinherited
port int?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
servers List<SocksRemoteConfig>?
no setterinherited
username String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_SocksClientConfig value)) → TResult

Available on SocksClientConfig, provided by the SocksClientConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SocksClientConfig value)?) → TResult?

Available on SocksClientConfig, provided by the SocksClientConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SocksClientConfig value)?, {required TResult orElse()}) → TResult

Available on SocksClientConfig, provided by the SocksClientConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(XrayAddress? address, int? port, int? level, String? email, String? username, String? password, List<SocksRemoteConfig>? servers)?, {required TResult orElse()}) → TResult

Available on SocksClientConfig, provided by the SocksClientConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(XrayAddress? address, int? port, int? level, String? email, String? username, String? password, List<SocksRemoteConfig>? servers)) → TResult

Available on SocksClientConfig, provided by the SocksClientConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(XrayAddress? address, int? port, int? level, String? email, String? username, String? password, List<SocksRemoteConfig>? servers)?) → TResult?

Available on SocksClientConfig, provided by the SocksClientConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited