SocksClientConfigPatterns extension

Adds pattern-matching-related methods to SocksClientConfig.

on

Methods

map<TResult extends Object?>(TResult $default(_SocksClientConfig value)) → TResult

Available on SocksClientConfig, provided by the SocksClientConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SocksClientConfig value)?) → TResult?

Available on SocksClientConfig, provided by the SocksClientConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SocksClientConfig value)?, {required TResult orElse()}) → TResult

Available on SocksClientConfig, provided by the SocksClientConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(XrayAddress? address, int? port, int? level, String? email, String? username, String? password, List<SocksRemoteConfig>? servers)?, {required TResult orElse()}) → TResult

Available on SocksClientConfig, provided by the SocksClientConfigPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(XrayAddress? address, int? port, int? level, String? email, String? username, String? password, List<SocksRemoteConfig>? servers)) → TResult

Available on SocksClientConfig, provided by the SocksClientConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(XrayAddress? address, int? port, int? level, String? email, String? username, String? password, List<SocksRemoteConfig>? servers)?) → TResult?

Available on SocksClientConfig, provided by the SocksClientConfigPatterns extension

A variant of when that fallback to returning null