SocksServerConfig class abstract
- Implemented types
- Available extensions
- Annotations
-
- @freezed
Constructors
-
SocksServerConfig({@JsonKey.new(name: 'auth') SocksAuthMethod? authMethod, List<
SocksAccount> ? accounts, bool? udp, @JsonKey.new(name: 'ip') XrayAddress? host, int? userLevel}) -
constfactory
- SocksServerConfig.fromJson(Object? json)
-
factory
Properties
-
accounts
→ List<
SocksAccount> ? -
no setterinherited
- authMethod → SocksAuthMethod?
-
no setterinherited
-
copyWith
→ $SocksServerConfigCopyWith<
SocksServerConfig> -
Create a copy of SocksServerConfig
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- host → XrayAddress?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- udp → bool?
-
no setterinherited
- userLevel → int?
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_SocksServerConfig value)) → TResult -
Available on SocksServerConfig, provided by the SocksServerConfigPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_SocksServerConfig value)?) → TResult? -
Available on SocksServerConfig, provided by the SocksServerConfigPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_SocksServerConfig value)?, {required TResult orElse()}) → TResult -
Available on SocksServerConfig, provided by the SocksServerConfigPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(SocksAuthMethod? authMethod, List< SocksAccount> ? accounts, bool? udp, XrayAddress? host, int? userLevel)?, {required TResult orElse()}) → TResult -
Available on SocksServerConfig, provided by the SocksServerConfigPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(SocksAuthMethod? authMethod, List< SocksAccount> ? accounts, bool? udp, XrayAddress? host, int? userLevel)) → TResult -
Available on SocksServerConfig, provided by the SocksServerConfigPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(SocksAuthMethod? authMethod, List< SocksAccount> ? accounts, bool? udp, XrayAddress? host, int? userLevel)?) → TResult? -
Available on SocksServerConfig, provided by the SocksServerConfigPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited