StrategyConfig class abstract

Available extensions
Annotations
  • @freezed

Constructors

StrategyConfig({BalancingStrategyType? type, XrayStrategySettings? settings})
const
factory
StrategyConfig.fromJson(Object? json)
factory

Properties

copyWith → $StrategyConfigCopyWith<StrategyConfig>
Create a copy of StrategyConfig with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings XrayStrategySettings?
no setterinherited
type BalancingStrategyType?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_StrategyConfig value)) → TResult

Available on StrategyConfig, provided by the StrategyConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_StrategyConfig value)?) → TResult?

Available on StrategyConfig, provided by the StrategyConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_StrategyConfig value)?, {required TResult orElse()}) → TResult

Available on StrategyConfig, provided by the StrategyConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(BalancingStrategyType? type, XrayStrategySettings? settings)?, {required TResult orElse()}) → TResult

Available on StrategyConfig, provided by the StrategyConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(BalancingStrategyType? type, XrayStrategySettings? settings)) → TResult

Available on StrategyConfig, provided by the StrategyConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(BalancingStrategyType? type, XrayStrategySettings? settings)?) → TResult?

Available on StrategyConfig, provided by the StrategyConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited