StrategyLeastLoadConfig class abstract

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

StrategyLeastLoadConfig({List<StrategyWeight>? costs, List<XrayDuration>? baselines, int? expected, XrayDuration? maxRTT, double? tolerance})
const
factory
StrategyLeastLoadConfig.fromJson(Object? json)
factory

Properties

baselines List<XrayDuration>?
no setterinherited
copyWith → $StrategyLeastLoadConfigCopyWith<StrategyLeastLoadConfig>
Create a copy of StrategyLeastLoadConfig with the given fields replaced by the non-null parameter values.
no setterinherited
costs List<StrategyWeight>?
no setterinherited
expected int?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
maxRTT XrayDuration?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tolerance double?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_StrategyLeastLoadConfig value)) → TResult

Available on StrategyLeastLoadConfig, provided by the StrategyLeastLoadConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_StrategyLeastLoadConfig value)?) → TResult?

Available on StrategyLeastLoadConfig, provided by the StrategyLeastLoadConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_StrategyLeastLoadConfig value)?, {required TResult orElse()}) → TResult

Available on StrategyLeastLoadConfig, provided by the StrategyLeastLoadConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(List<StrategyWeight>? costs, List<XrayDuration>? baselines, int? expected, XrayDuration? maxRTT, double? tolerance)?, {required TResult orElse()}) → TResult

Available on StrategyLeastLoadConfig, provided by the StrategyLeastLoadConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(List<StrategyWeight>? costs, List<XrayDuration>? baselines, int? expected, XrayDuration? maxRTT, double? tolerance)) → TResult

Available on StrategyLeastLoadConfig, provided by the StrategyLeastLoadConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(List<StrategyWeight>? costs, List<XrayDuration>? baselines, int? expected, XrayDuration? maxRTT, double? tolerance)?) → TResult?

Available on StrategyLeastLoadConfig, provided by the StrategyLeastLoadConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited