StrategyLeastLoadConfigPatterns extension

Adds pattern-matching-related methods to StrategyLeastLoadConfig.

on

Methods

map<TResult extends Object?>(TResult $default(_StrategyLeastLoadConfig value)) → TResult

Available on StrategyLeastLoadConfig, provided by the StrategyLeastLoadConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_StrategyLeastLoadConfig value)?) → TResult?

Available on StrategyLeastLoadConfig, provided by the StrategyLeastLoadConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_StrategyLeastLoadConfig value)?, {required TResult orElse()}) → TResult

Available on StrategyLeastLoadConfig, provided by the StrategyLeastLoadConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(List<StrategyWeight>? costs, List<XrayDuration>? baselines, int? expected, XrayDuration? maxRTT, double? tolerance)?, {required TResult orElse()}) → TResult

Available on StrategyLeastLoadConfig, provided by the StrategyLeastLoadConfigPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(List<StrategyWeight>? costs, List<XrayDuration>? baselines, int? expected, XrayDuration? maxRTT, double? tolerance)) → TResult

Available on StrategyLeastLoadConfig, provided by the StrategyLeastLoadConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(List<StrategyWeight>? costs, List<XrayDuration>? baselines, int? expected, XrayDuration? maxRTT, double? tolerance)?) → TResult?

Available on StrategyLeastLoadConfig, provided by the StrategyLeastLoadConfigPatterns extension

A variant of when that fallback to returning null