toString method

  1. @override
String toString()
inherited

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  return 'StreamConfig(address: $address, port: $port, network: $network, security: $security, finalmask: $finalmask, rawSettings: $rawSettings, tcpSettings: $tcpSettings, xhttpSettings: $xhttpSettings, kcpSettings: $kcpSettings, wsSettings: $wsSettings, httpupgradeSettings: $httpupgradeSettings, splithttpSettings: $splithttpSettings, grpcSettings: $grpcSettings, hysteriaSettings: $hysteriaSettings, tlsSettings: $tlsSettings, realitySettings: $realitySettings, sockopt: $sockopt)';
}