StreamConfigPatterns extension

Adds pattern-matching-related methods to StreamConfig.

on

Methods

map<TResult extends Object?>(TResult $default(_StreamConfig value)) → TResult

Available on StreamConfig, provided by the StreamConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_StreamConfig value)?) → TResult?

Available on StreamConfig, provided by the StreamConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_StreamConfig value)?, {required TResult orElse()}) → TResult

Available on StreamConfig, provided by the StreamConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(XrayAddress? address, int? port, TransportProtocol? network, SecurityProtocol? security, FinalMask? finalmask, TCPConfig? rawSettings, TCPConfig? tcpSettings, SplitHTTPConfig? xhttpSettings, KCPConfig? kcpSettings, WebSocketConfig? wsSettings, HttpUpgradeConfig? httpupgradeSettings, SplitHTTPConfig? splithttpSettings, GRPCConfig? grpcSettings, HysteriaConfig? hysteriaSettings, TLSConfig? tlsSettings, REALITYConfig? realitySettings, SocketConfig? sockopt)?, {required TResult orElse()}) → TResult

Available on StreamConfig, provided by the StreamConfigPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(XrayAddress? address, int? port, TransportProtocol? network, SecurityProtocol? security, FinalMask? finalmask, TCPConfig? rawSettings, TCPConfig? tcpSettings, SplitHTTPConfig? xhttpSettings, KCPConfig? kcpSettings, WebSocketConfig? wsSettings, HttpUpgradeConfig? httpupgradeSettings, SplitHTTPConfig? splithttpSettings, GRPCConfig? grpcSettings, HysteriaConfig? hysteriaSettings, TLSConfig? tlsSettings, REALITYConfig? realitySettings, SocketConfig? sockopt)) → TResult

Available on StreamConfig, provided by the StreamConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(XrayAddress? address, int? port, TransportProtocol? network, SecurityProtocol? security, FinalMask? finalmask, TCPConfig? rawSettings, TCPConfig? tcpSettings, SplitHTTPConfig? xhttpSettings, KCPConfig? kcpSettings, WebSocketConfig? wsSettings, HttpUpgradeConfig? httpupgradeSettings, SplitHTTPConfig? splithttpSettings, GRPCConfig? grpcSettings, HysteriaConfig? hysteriaSettings, TLSConfig? tlsSettings, REALITYConfig? realitySettings, SocketConfig? sockopt)?) → TResult?

Available on StreamConfig, provided by the StreamConfigPatterns extension

A variant of when that fallback to returning null