Sudoku class abstract

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

Sudoku({String? password, @JsonKey.new(name: 'ascii') String? ascii, String? customTable, @JsonKey.new(name: 'custom_table') String? legacyCustomTable, List<String>? customTables, @JsonKey.new(name: 'custom_tables') List<String>? legacyCustomSets, int? paddingMin, @JsonKey.new(name: 'padding_min') int? legacyPaddingMin, int? paddingMax, @JsonKey.new(name: 'padding_max') int? legacyPaddingMax})
const
factory
Sudoku.fromJson(Object? json)
factory

Properties

ascii String?
no setterinherited
copyWith → $SudokuCopyWith<Sudoku>
Create a copy of Sudoku with the given fields replaced by the non-null parameter values.
no setterinherited
customTable String?
no setterinherited
customTables List<String>?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
legacyCustomSets List<String>?
no setterinherited
legacyCustomTable String?
no setterinherited
legacyPaddingMax int?
no setterinherited
legacyPaddingMin int?
no setterinherited
paddingMax int?
no setterinherited
paddingMin int?
no setterinherited
password String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Sudoku value)) → TResult

Available on Sudoku, provided by the SudokuPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Sudoku value)?) → TResult?

Available on Sudoku, provided by the SudokuPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Sudoku value)?, {required TResult orElse()}) → TResult

Available on Sudoku, provided by the SudokuPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? password, String? ascii, String? customTable, String? legacyCustomTable, List<String>? customTables, List<String>? legacyCustomSets, int? paddingMin, int? legacyPaddingMin, int? paddingMax, int? legacyPaddingMax)?, {required TResult orElse()}) → TResult

Available on Sudoku, provided by the SudokuPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? password, String? ascii, String? customTable, String? legacyCustomTable, List<String>? customTables, List<String>? legacyCustomSets, int? paddingMin, int? legacyPaddingMin, int? paddingMax, int? legacyPaddingMax)) → TResult

Available on Sudoku, provided by the SudokuPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? password, String? ascii, String? customTable, String? legacyCustomTable, List<String>? customTables, List<String>? legacyCustomSets, int? paddingMin, int? legacyPaddingMin, int? paddingMax, int? legacyPaddingMax)?) → TResult?

Available on Sudoku, provided by the SudokuPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited