SystemPolicyPatterns extension

Adds pattern-matching-related methods to SystemPolicy.

on

Methods

map<TResult extends Object?>(TResult $default(_SystemPolicy value)) → TResult

Available on SystemPolicy, provided by the SystemPolicyPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SystemPolicy value)?) → TResult?

Available on SystemPolicy, provided by the SystemPolicyPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SystemPolicy value)?, {required TResult orElse()}) → TResult

Available on SystemPolicy, provided by the SystemPolicyPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(bool? statsInboundUplink, bool? statsInboundDownlink, bool? statsOutboundUplink, bool? statsOutboundDownlink)?, {required TResult orElse()}) → TResult

Available on SystemPolicy, provided by the SystemPolicyPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(bool? statsInboundUplink, bool? statsInboundDownlink, bool? statsOutboundUplink, bool? statsOutboundDownlink)) → TResult

Available on SystemPolicy, provided by the SystemPolicyPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(bool? statsInboundUplink, bool? statsInboundDownlink, bool? statsOutboundUplink, bool? statsOutboundDownlink)?) → TResult?

Available on SystemPolicy, provided by the SystemPolicyPatterns extension

A variant of when that fallback to returning null