TCPConfigPatterns extension

Adds pattern-matching-related methods to TCPConfig.

on

Methods

map<TResult extends Object?>(TResult $default(_TCPConfig value)) → TResult

Available on TCPConfig, provided by the TCPConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_TCPConfig value)?) → TResult?

Available on TCPConfig, provided by the TCPConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_TCPConfig value)?, {required TResult orElse()}) → TResult

Available on TCPConfig, provided by the TCPConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(TCPHeaderConfig? header, bool? acceptProxyProtocol)?, {required TResult orElse()}) → TResult

Available on TCPConfig, provided by the TCPConfigPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(TCPHeaderConfig? header, bool? acceptProxyProtocol)) → TResult

Available on TCPConfig, provided by the TCPConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(TCPHeaderConfig? header, bool? acceptProxyProtocol)?) → TResult?

Available on TCPConfig, provided by the TCPConfigPatterns extension

A variant of when that fallback to returning null