TCPItem class abstract

Available extensions
Annotations
  • @freezed

Constructors

TCPItem({XrayInt32Range? delay, int? rand, XrayInt32Range? randRange, String? capture, String? type, String? reuse, CustomTransform? transform, Object? packet})
const
factory
TCPItem.fromJson(Object? json)
factory

Properties

capture String?
no setterinherited
copyWith → $TCPItemCopyWith<TCPItem>
Create a copy of TCPItem with the given fields replaced by the non-null parameter values.
no setterinherited
delay XrayInt32Range?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
packet Object?
no setterinherited
rand int?
no setterinherited
randRange XrayInt32Range?
no setterinherited
reuse String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transform CustomTransform?
no setterinherited
type String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_TCPItem value)) → TResult

Available on TCPItem, provided by the TCPItemPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_TCPItem value)?) → TResult?

Available on TCPItem, provided by the TCPItemPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_TCPItem value)?, {required TResult orElse()}) → TResult

Available on TCPItem, provided by the TCPItemPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(XrayInt32Range? delay, int? rand, XrayInt32Range? randRange, String? capture, String? type, String? reuse, CustomTransform? transform, Object? packet)?, {required TResult orElse()}) → TResult

Available on TCPItem, provided by the TCPItemPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(XrayInt32Range? delay, int? rand, XrayInt32Range? randRange, String? capture, String? type, String? reuse, CustomTransform? transform, Object? packet)) → TResult

Available on TCPItem, provided by the TCPItemPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(XrayInt32Range? delay, int? rand, XrayInt32Range? randRange, String? capture, String? type, String? reuse, CustomTransform? transform, Object? packet)?) → TResult?

Available on TCPItem, provided by the TCPItemPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited