TLSConfig class abstract

Available extensions
Annotations
  • @freezed

Constructors

TLSConfig({bool? allowInsecure, @JsonKey.new(name: 'certificates') List<TLSCertConfig>? certs, String? serverName, @JsonKey.new(name: 'alpn') XrayStringList? alpn, bool? enableSessionResumption, bool? disableSystemRoot, String? minVersion, String? maxVersion, String? cipherSuites, String? fingerprint, @JsonKey.new(name: 'rejectUnknownSni') bool? rejectUnknownSNI, XrayStringList? curvePreferences, String? masterKeyLog, String? pinnedPeerCertSha256, String? verifyPeerCertByName, List<String>? verifyPeerCertInNames, String? echServerKeys, String? echConfigList, ECHForceQuery? echForceQuery, @JsonKey.new(name: 'echSockopt') SocketConfig? echSocketSettings})
const
factory
TLSConfig.fromJson(Object? json)
factory

Properties

allowInsecure bool?
no setterinherited
alpn XrayStringList?
no setterinherited
certs List<TLSCertConfig>?
no setterinherited
cipherSuites String?
no setterinherited
copyWith → $TLSConfigCopyWith<TLSConfig>
Create a copy of TLSConfig with the given fields replaced by the non-null parameter values.
no setterinherited
curvePreferences XrayStringList?
no setterinherited
disableSystemRoot bool?
no setterinherited
echConfigList String?
no setterinherited
echForceQuery ECHForceQuery?
no setterinherited
echServerKeys String?
no setterinherited
echSocketSettings SocketConfig?
no setterinherited
enableSessionResumption bool?
no setterinherited
fingerprint String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
masterKeyLog String?
no setterinherited
maxVersion String?
no setterinherited
minVersion String?
no setterinherited
pinnedPeerCertSha256 String?
no setterinherited
rejectUnknownSNI bool?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverName String?
no setterinherited
verifyPeerCertByName String?
no setterinherited
verifyPeerCertInNames List<String>?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_TLSConfig value)) → TResult

Available on TLSConfig, provided by the TLSConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_TLSConfig value)?) → TResult?

Available on TLSConfig, provided by the TLSConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_TLSConfig value)?, {required TResult orElse()}) → TResult

Available on TLSConfig, provided by the TLSConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(bool? allowInsecure, List<TLSCertConfig>? certs, String? serverName, XrayStringList? alpn, bool? enableSessionResumption, bool? disableSystemRoot, String? minVersion, String? maxVersion, String? cipherSuites, String? fingerprint, bool? rejectUnknownSNI, XrayStringList? curvePreferences, String? masterKeyLog, String? pinnedPeerCertSha256, String? verifyPeerCertByName, List<String>? verifyPeerCertInNames, String? echServerKeys, String? echConfigList, ECHForceQuery? echForceQuery, SocketConfig? echSocketSettings)?, {required TResult orElse()}) → TResult

Available on TLSConfig, provided by the TLSConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(bool? allowInsecure, List<TLSCertConfig>? certs, String? serverName, XrayStringList? alpn, bool? enableSessionResumption, bool? disableSystemRoot, String? minVersion, String? maxVersion, String? cipherSuites, String? fingerprint, bool? rejectUnknownSNI, XrayStringList? curvePreferences, String? masterKeyLog, String? pinnedPeerCertSha256, String? verifyPeerCertByName, List<String>? verifyPeerCertInNames, String? echServerKeys, String? echConfigList, ECHForceQuery? echForceQuery, SocketConfig? echSocketSettings)) → TResult

Available on TLSConfig, provided by the TLSConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(bool? allowInsecure, List<TLSCertConfig>? certs, String? serverName, XrayStringList? alpn, bool? enableSessionResumption, bool? disableSystemRoot, String? minVersion, String? maxVersion, String? cipherSuites, String? fingerprint, bool? rejectUnknownSNI, XrayStringList? curvePreferences, String? masterKeyLog, String? pinnedPeerCertSha256, String? verifyPeerCertByName, List<String>? verifyPeerCertInNames, String? echServerKeys, String? echConfigList, ECHForceQuery? echForceQuery, SocketConfig? echSocketSettings)?) → TResult?

Available on TLSConfig, provided by the TLSConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited