TrojanClientConfig class abstract

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

TrojanClientConfig({XrayAddress? address, int? port, int? level, String? email, String? password, String? flow, List<TrojanServerTarget>? servers})
const
factory
TrojanClientConfig.fromJson(Object? json)
factory
TrojanClientConfig.single({required XrayAddress address, required int port, int? level, String? email, required String password})
factory

Properties

address XrayAddress?
no setterinherited
copyWith → $TrojanClientConfigCopyWith<TrojanClientConfig>
Create a copy of TrojanClientConfig with the given fields replaced by the non-null parameter values.
no setterinherited
email String?
no setterinherited
flow String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
level int?
no setterinherited
password String?
no setterinherited
port int?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
servers List<TrojanServerTarget>?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_TrojanClientConfig value)) → TResult

Available on TrojanClientConfig, provided by the TrojanClientConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_TrojanClientConfig value)?) → TResult?

Available on TrojanClientConfig, provided by the TrojanClientConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_TrojanClientConfig value)?, {required TResult orElse()}) → TResult

Available on TrojanClientConfig, provided by the TrojanClientConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(XrayAddress? address, int? port, int? level, String? email, String? password, String? flow, List<TrojanServerTarget>? servers)?, {required TResult orElse()}) → TResult

Available on TrojanClientConfig, provided by the TrojanClientConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(XrayAddress? address, int? port, int? level, String? email, String? password, String? flow, List<TrojanServerTarget>? servers)) → TResult

Available on TrojanClientConfig, provided by the TrojanClientConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(XrayAddress? address, int? port, int? level, String? email, String? password, String? flow, List<TrojanServerTarget>? servers)?) → TResult?

Available on TrojanClientConfig, provided by the TrojanClientConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited