TrojanServerConfig class abstract
- Implemented types
- Available extensions
- Annotations
-
- @freezed
Constructors
-
TrojanServerConfig({List<
TrojanUserConfig> ? clients, List<TrojanInboundFallback> ? fallbacks}) -
constfactory
- TrojanServerConfig.fromJson(Object? json)
-
factory
-
TrojanServerConfig.single({required TrojanUserConfig client, List<
TrojanInboundFallback> ? fallbacks}) -
factory
Properties
-
clients
→ List<
TrojanUserConfig> ? -
no setterinherited
-
copyWith
→ $TrojanServerConfigCopyWith<
TrojanServerConfig> -
Create a copy of TrojanServerConfig
with the given fields replaced by the non-null parameter values.
no setterinherited
-
fallbacks
→ List<
TrojanInboundFallback> ? -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_TrojanServerConfig value)) → TResult -
Available on TrojanServerConfig, provided by the TrojanServerConfigPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_TrojanServerConfig value)?) → TResult? -
Available on TrojanServerConfig, provided by the TrojanServerConfigPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_TrojanServerConfig value)?, {required TResult orElse()}) → TResult -
Available on TrojanServerConfig, provided by the TrojanServerConfigPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(List< TrojanUserConfig> ? clients, List<TrojanInboundFallback> ? fallbacks)?, {required TResult orElse()}) → TResult -
Available on TrojanServerConfig, provided by the TrojanServerConfigPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(List< TrojanUserConfig> ? clients, List<TrojanInboundFallback> ? fallbacks)) → TResult -
Available on TrojanServerConfig, provided by the TrojanServerConfigPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(List< TrojanUserConfig> ? clients, List<TrojanInboundFallback> ? fallbacks)?) → TResult? -
Available on TrojanServerConfig, provided by the TrojanServerConfigPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited