TrojanUserConfig class abstract

Available extensions
Annotations
  • @freezed

Constructors

TrojanUserConfig({required String password, int? level, String? email, String? flow})
const
factory
TrojanUserConfig.fromJson(Object? json)
factory

Properties

copyWith → $TrojanUserConfigCopyWith<TrojanUserConfig>
Create a copy of TrojanUserConfig with the given fields replaced by the non-null parameter values.
no setterinherited
email String?
no setterinherited
flow String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
level int?
no setterinherited
password String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_TrojanUserConfig value)) → TResult

Available on TrojanUserConfig, provided by the TrojanUserConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_TrojanUserConfig value)?) → TResult?

Available on TrojanUserConfig, provided by the TrojanUserConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_TrojanUserConfig value)?, {required TResult orElse()}) → TResult

Available on TrojanUserConfig, provided by the TrojanUserConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String password, int? level, String? email, String? flow)?, {required TResult orElse()}) → TResult

Available on TrojanUserConfig, provided by the TrojanUserConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String password, int? level, String? email, String? flow)) → TResult

Available on TrojanUserConfig, provided by the TrojanUserConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String password, int? level, String? email, String? flow)?) → TResult?

Available on TrojanUserConfig, provided by the TrojanUserConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited