TrojanUserConfigPatterns extension

Adds pattern-matching-related methods to TrojanUserConfig.

on

Methods

map<TResult extends Object?>(TResult $default(_TrojanUserConfig value)) → TResult

Available on TrojanUserConfig, provided by the TrojanUserConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_TrojanUserConfig value)?) → TResult?

Available on TrojanUserConfig, provided by the TrojanUserConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_TrojanUserConfig value)?, {required TResult orElse()}) → TResult

Available on TrojanUserConfig, provided by the TrojanUserConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String password, int? level, String? email, String? flow)?, {required TResult orElse()}) → TResult

Available on TrojanUserConfig, provided by the TrojanUserConfigPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String password, int? level, String? email, String? flow)) → TResult

Available on TrojanUserConfig, provided by the TrojanUserConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String password, int? level, String? email, String? flow)?) → TResult?

Available on TrojanUserConfig, provided by the TrojanUserConfigPatterns extension

A variant of when that fallback to returning null