TunConfigPatterns extension

Adds pattern-matching-related methods to TunConfig.

on

Methods

map<TResult extends Object?>(TResult $default(_TunConfig value)) → TResult

Available on TunConfig, provided by the TunConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_TunConfig value)?) → TResult?

Available on TunConfig, provided by the TunConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_TunConfig value)?, {required TResult orElse()}) → TResult

Available on TunConfig, provided by the TunConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? name, int? mtu, List<String>? gateway, List<String>? dns, int? userLevel, List<String>? autoSystemRoutingTable, String? autoOutboundsInterface)?, {required TResult orElse()}) → TResult

Available on TunConfig, provided by the TunConfigPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String? name, int? mtu, List<String>? gateway, List<String>? dns, int? userLevel, List<String>? autoSystemRoutingTable, String? autoOutboundsInterface)) → TResult

Available on TunConfig, provided by the TunConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? name, int? mtu, List<String>? gateway, List<String>? dns, int? userLevel, List<String>? autoSystemRoutingTable, String? autoOutboundsInterface)?) → TResult?

Available on TunConfig, provided by the TunConfigPatterns extension

A variant of when that fallback to returning null