UdpHop class abstract

Available extensions
Annotations
  • @freezed

Constructors

UdpHop({XrayPortList? ports, XrayInt32Range? interval})
const
factory
UdpHop.fromJson(Object? json)
factory

Properties

copyWith → $UdpHopCopyWith<UdpHop>
Create a copy of UdpHop with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
interval XrayInt32Range?
no setterinherited
ports XrayPortList?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_UdpHop value)) → TResult

Available on UdpHop, provided by the UdpHopPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_UdpHop value)?) → TResult?

Available on UdpHop, provided by the UdpHopPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_UdpHop value)?, {required TResult orElse()}) → TResult

Available on UdpHop, provided by the UdpHopPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(XrayPortList? ports, XrayInt32Range? interval)?, {required TResult orElse()}) → TResult

Available on UdpHop, provided by the UdpHopPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(XrayPortList? ports, XrayInt32Range? interval)) → TResult

Available on UdpHop, provided by the UdpHopPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(XrayPortList? ports, XrayInt32Range? interval)?) → TResult?

Available on UdpHop, provided by the UdpHopPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited