VLessInboundConfig class abstract

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

VLessInboundConfig({List<VLessUser>? clients, required String decryption, List<VLessInboundFallback>? fallbacks, String? flow, List<int>? testseed})
const
factory
VLessInboundConfig.fromJson(Object? json)
factory
VLessInboundConfig.single({required VLessUser client, required String decryption, List<VLessInboundFallback>? fallbacks, String? flow, List<int>? testseed})
factory

Properties

clients List<VLessUser>?
no setterinherited
copyWith → $VLessInboundConfigCopyWith<VLessInboundConfig>
Create a copy of VLessInboundConfig with the given fields replaced by the non-null parameter values.
no setterinherited
decryption String
no setterinherited
fallbacks List<VLessInboundFallback>?
no setterinherited
flow String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
testseed List<int>?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_VLessInboundConfig value)) → TResult

Available on VLessInboundConfig, provided by the VLessInboundConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_VLessInboundConfig value)?) → TResult?

Available on VLessInboundConfig, provided by the VLessInboundConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_VLessInboundConfig value)?, {required TResult orElse()}) → TResult

Available on VLessInboundConfig, provided by the VLessInboundConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(List<VLessUser>? clients, String decryption, List<VLessInboundFallback>? fallbacks, String? flow, List<int>? testseed)?, {required TResult orElse()}) → TResult

Available on VLessInboundConfig, provided by the VLessInboundConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(List<VLessUser>? clients, String decryption, List<VLessInboundFallback>? fallbacks, String? flow, List<int>? testseed)) → TResult

Available on VLessInboundConfig, provided by the VLessInboundConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(List<VLessUser>? clients, String decryption, List<VLessInboundFallback>? fallbacks, String? flow, List<int>? testseed)?) → TResult?

Available on VLessInboundConfig, provided by the VLessInboundConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited