VLessInboundConfigPatterns extension

Adds pattern-matching-related methods to VLessInboundConfig.

on

Methods

map<TResult extends Object?>(TResult $default(_VLessInboundConfig value)) → TResult

Available on VLessInboundConfig, provided by the VLessInboundConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_VLessInboundConfig value)?) → TResult?

Available on VLessInboundConfig, provided by the VLessInboundConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_VLessInboundConfig value)?, {required TResult orElse()}) → TResult

Available on VLessInboundConfig, provided by the VLessInboundConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(List<VLessUser>? clients, String decryption, List<VLessInboundFallback>? fallbacks, String? flow, List<int>? testseed)?, {required TResult orElse()}) → TResult

Available on VLessInboundConfig, provided by the VLessInboundConfigPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(List<VLessUser>? clients, String decryption, List<VLessInboundFallback>? fallbacks, String? flow, List<int>? testseed)) → TResult

Available on VLessInboundConfig, provided by the VLessInboundConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(List<VLessUser>? clients, String decryption, List<VLessInboundFallback>? fallbacks, String? flow, List<int>? testseed)?) → TResult?

Available on VLessInboundConfig, provided by the VLessInboundConfigPatterns extension

A variant of when that fallback to returning null