VLessOutboundConfigPatterns extension

Adds pattern-matching-related methods to VLessOutboundConfig.

on

Methods

map<TResult extends Object?>(TResult $default(_VLessOutboundConfig value)) → TResult

Available on VLessOutboundConfig, provided by the VLessOutboundConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_VLessOutboundConfig value)?) → TResult?

Available on VLessOutboundConfig, provided by the VLessOutboundConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_VLessOutboundConfig value)?, {required TResult orElse()}) → TResult

Available on VLessOutboundConfig, provided by the VLessOutboundConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(XrayAddress? address, int? port, int? level, String? email, String? id, String? flow, String? seed, String? encryption, VLessReverseConfig? reverse, int? testpre, List<int>? testseed, List<VLessOutboundVnext>? vnext)?, {required TResult orElse()}) → TResult

Available on VLessOutboundConfig, provided by the VLessOutboundConfigPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(XrayAddress? address, int? port, int? level, String? email, String? id, String? flow, String? seed, String? encryption, VLessReverseConfig? reverse, int? testpre, List<int>? testseed, List<VLessOutboundVnext>? vnext)) → TResult

Available on VLessOutboundConfig, provided by the VLessOutboundConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(XrayAddress? address, int? port, int? level, String? email, String? id, String? flow, String? seed, String? encryption, VLessReverseConfig? reverse, int? testpre, List<int>? testseed, List<VLessOutboundVnext>? vnext)?) → TResult?

Available on VLessOutboundConfig, provided by the VLessOutboundConfigPatterns extension

A variant of when that fallback to returning null