VLessUser class abstract

Available extensions
Annotations
  • @freezed

Constructors

VLessUser({String? email, int? level, required String id, String? flow, String? seed, String? encryption, VLessReverseConfig? reverse, int? testpre, List<int>? testseed})
const
factory
VLessUser.fromJson(Object? json)
factory

Properties

copyWith → $VLessUserCopyWith<VLessUser>
Create a copy of VLessUser with the given fields replaced by the non-null parameter values.
no setterinherited
email String?
no setterinherited
encryption String?
no setterinherited
flow String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
no setterinherited
level int?
no setterinherited
reverse VLessReverseConfig?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seed String?
no setterinherited
testpre int?
no setterinherited
testseed List<int>?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_VLessUser value)) → TResult

Available on VLessUser, provided by the VLessUserPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_VLessUser value)?) → TResult?

Available on VLessUser, provided by the VLessUserPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_VLessUser value)?, {required TResult orElse()}) → TResult

Available on VLessUser, provided by the VLessUserPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? email, int? level, String id, String? flow, String? seed, String? encryption, VLessReverseConfig? reverse, int? testpre, List<int>? testseed)?, {required TResult orElse()}) → TResult

Available on VLessUser, provided by the VLessUserPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? email, int? level, String id, String? flow, String? seed, String? encryption, VLessReverseConfig? reverse, int? testpre, List<int>? testseed)) → TResult

Available on VLessUser, provided by the VLessUserPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? email, int? level, String id, String? flow, String? seed, String? encryption, VLessReverseConfig? reverse, int? testpre, List<int>? testseed)?) → TResult?

Available on VLessUser, provided by the VLessUserPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited