VLessUserPatterns extension

Adds pattern-matching-related methods to VLessUser.

on

Methods

map<TResult extends Object?>(TResult $default(_VLessUser value)) → TResult

Available on VLessUser, provided by the VLessUserPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_VLessUser value)?) → TResult?

Available on VLessUser, provided by the VLessUserPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_VLessUser value)?, {required TResult orElse()}) → TResult

Available on VLessUser, provided by the VLessUserPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? email, int? level, String id, String? flow, String? seed, String? encryption, VLessReverseConfig? reverse, int? testpre, List<int>? testseed)?, {required TResult orElse()}) → TResult

Available on VLessUser, provided by the VLessUserPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String? email, int? level, String id, String? flow, String? seed, String? encryption, VLessReverseConfig? reverse, int? testpre, List<int>? testseed)) → TResult

Available on VLessUser, provided by the VLessUserPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? email, int? level, String id, String? flow, String? seed, String? encryption, VLessReverseConfig? reverse, int? testpre, List<int>? testseed)?) → TResult?

Available on VLessUser, provided by the VLessUserPatterns extension

A variant of when that fallback to returning null