VMessAccount class abstract

Available extensions
Annotations
  • @freezed

Constructors

VMessAccount({required String id, VmessSecurity? security, String? experiments})
const
factory
VMessAccount.fromJson(Object? json)
factory

Properties

copyWith → $VMessAccountCopyWith<VMessAccount>
Create a copy of VMessAccount with the given fields replaced by the non-null parameter values.
no setterinherited
experiments String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
security VmessSecurity?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_VMessAccount value)) → TResult

Available on VMessAccount, provided by the VMessAccountPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_VMessAccount value)?) → TResult?

Available on VMessAccount, provided by the VMessAccountPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_VMessAccount value)?, {required TResult orElse()}) → TResult

Available on VMessAccount, provided by the VMessAccountPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String id, VmessSecurity? security, String? experiments)?, {required TResult orElse()}) → TResult

Available on VMessAccount, provided by the VMessAccountPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String id, VmessSecurity? security, String? experiments)) → TResult

Available on VMessAccount, provided by the VMessAccountPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String id, VmessSecurity? security, String? experiments)?) → TResult?

Available on VMessAccount, provided by the VMessAccountPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited