VMessInboundConfig class abstract

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

VMessInboundConfig({@JsonKey.new(name: 'clients') List<VMessUser>? users, @JsonKey.new(name: 'default') VMessDefaultConfig? defaults})
const
factory
VMessInboundConfig.fromJson(Object? json)
factory
VMessInboundConfig.single({required VMessUser user, VMessDefaultConfig? defaults})
factory

Properties

copyWith → $VMessInboundConfigCopyWith<VMessInboundConfig>
Create a copy of VMessInboundConfig with the given fields replaced by the non-null parameter values.
no setterinherited
defaults VMessDefaultConfig?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
users List<VMessUser>?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_VMessInboundConfig value)) → TResult

Available on VMessInboundConfig, provided by the VMessInboundConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_VMessInboundConfig value)?) → TResult?

Available on VMessInboundConfig, provided by the VMessInboundConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_VMessInboundConfig value)?, {required TResult orElse()}) → TResult

Available on VMessInboundConfig, provided by the VMessInboundConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(List<VMessUser>? users, VMessDefaultConfig? defaults)?, {required TResult orElse()}) → TResult

Available on VMessInboundConfig, provided by the VMessInboundConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(List<VMessUser>? users, VMessDefaultConfig? defaults)) → TResult

Available on VMessInboundConfig, provided by the VMessInboundConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(List<VMessUser>? users, VMessDefaultConfig? defaults)?) → TResult?

Available on VMessInboundConfig, provided by the VMessInboundConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited