VMessUser class abstract

Available extensions
Annotations
  • @freezed

Constructors

VMessUser({String? email, int? level, required String id, VmessSecurity? security, String? experiments})
const
factory
VMessUser.fromJson(Object? json)
factory

Properties

copyWith → $VMessUserCopyWith<VMessUser>
Create a copy of VMessUser with the given fields replaced by the non-null parameter values.
no setterinherited
email String?
no setterinherited
experiments String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
no setterinherited
level int?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
security VmessSecurity?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_VMessUser value)) → TResult

Available on VMessUser, provided by the VMessUserPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_VMessUser value)?) → TResult?

Available on VMessUser, provided by the VMessUserPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_VMessUser value)?, {required TResult orElse()}) → TResult

Available on VMessUser, provided by the VMessUserPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? email, int? level, String id, VmessSecurity? security, String? experiments)?, {required TResult orElse()}) → TResult

Available on VMessUser, provided by the VMessUserPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? email, int? level, String id, VmessSecurity? security, String? experiments)) → TResult

Available on VMessUser, provided by the VMessUserPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? email, int? level, String id, VmessSecurity? security, String? experiments)?) → TResult?

Available on VMessUser, provided by the VMessUserPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited