WebhookRuleConfig class abstract

Available extensions
Annotations
  • @freezed

Constructors

WebhookRuleConfig({required String url, int? deduplication, Map<String, String>? headers})
const
factory
WebhookRuleConfig.fromJson(Object? json)
factory

Properties

copyWith → $WebhookRuleConfigCopyWith<WebhookRuleConfig>
Create a copy of WebhookRuleConfig with the given fields replaced by the non-null parameter values.
no setterinherited
deduplication int?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_WebhookRuleConfig value)) → TResult

Available on WebhookRuleConfig, provided by the WebhookRuleConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_WebhookRuleConfig value)?) → TResult?

Available on WebhookRuleConfig, provided by the WebhookRuleConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_WebhookRuleConfig value)?, {required TResult orElse()}) → TResult

Available on WebhookRuleConfig, provided by the WebhookRuleConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String url, int? deduplication, Map<String, String>? headers)?, {required TResult orElse()}) → TResult

Available on WebhookRuleConfig, provided by the WebhookRuleConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String url, int? deduplication, Map<String, String>? headers)) → TResult

Available on WebhookRuleConfig, provided by the WebhookRuleConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String url, int? deduplication, Map<String, String>? headers)?) → TResult?

Available on WebhookRuleConfig, provided by the WebhookRuleConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited