WireGuardConfig class abstract

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

WireGuardConfig({bool? noKernelTun, required String secretKey, List<String>? address, List<WireGuardPeerConfig>? peers, @JsonKey.new(name: 'mtu') int? mtu, @JsonKey.new(name: 'workers') int? numWorkers, List<int>? reserved, XrayTargetStrategy? domainStrategy})
const
factory
WireGuardConfig.fromJson(Object? json)
factory

Properties

address List<String>?
no setterinherited
copyWith → $WireGuardConfigCopyWith<WireGuardConfig>
Create a copy of WireGuardConfig with the given fields replaced by the non-null parameter values.
no setterinherited
domainStrategy XrayTargetStrategy?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
mtu int?
no setterinherited
noKernelTun bool?
no setterinherited
numWorkers int?
no setterinherited
peers List<WireGuardPeerConfig>?
no setterinherited
reserved List<int>?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretKey String
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_WireGuardConfig value)) → TResult

Available on WireGuardConfig, provided by the WireGuardConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_WireGuardConfig value)?) → TResult?

Available on WireGuardConfig, provided by the WireGuardConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_WireGuardConfig value)?, {required TResult orElse()}) → TResult

Available on WireGuardConfig, provided by the WireGuardConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(bool? noKernelTun, String secretKey, List<String>? address, List<WireGuardPeerConfig>? peers, int? mtu, int? numWorkers, List<int>? reserved, XrayTargetStrategy? domainStrategy)?, {required TResult orElse()}) → TResult

Available on WireGuardConfig, provided by the WireGuardConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(bool? noKernelTun, String secretKey, List<String>? address, List<WireGuardPeerConfig>? peers, int? mtu, int? numWorkers, List<int>? reserved, XrayTargetStrategy? domainStrategy)) → TResult

Available on WireGuardConfig, provided by the WireGuardConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(bool? noKernelTun, String secretKey, List<String>? address, List<WireGuardPeerConfig>? peers, int? mtu, int? numWorkers, List<int>? reserved, XrayTargetStrategy? domainStrategy)?) → TResult?

Available on WireGuardConfig, provided by the WireGuardConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited