WireGuardPeerConfig class abstract

Available extensions
Annotations
  • @freezed

Constructors

WireGuardPeerConfig({String? publicKey, String? preSharedKey, String? endpoint, int? keepAlive, List<String>? allowedIPs})
const
factory
WireGuardPeerConfig.fromJson(Object? json)
factory

Properties

allowedIPs List<String>?
no setterinherited
copyWith → $WireGuardPeerConfigCopyWith<WireGuardPeerConfig>
Create a copy of WireGuardPeerConfig with the given fields replaced by the non-null parameter values.
no setterinherited
endpoint String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
keepAlive int?
no setterinherited
preSharedKey String?
no setterinherited
publicKey String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_WireGuardPeerConfig value)) → TResult

Available on WireGuardPeerConfig, provided by the WireGuardPeerConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_WireGuardPeerConfig value)?) → TResult?

Available on WireGuardPeerConfig, provided by the WireGuardPeerConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_WireGuardPeerConfig value)?, {required TResult orElse()}) → TResult

Available on WireGuardPeerConfig, provided by the WireGuardPeerConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? publicKey, String? preSharedKey, String? endpoint, int? keepAlive, List<String>? allowedIPs)?, {required TResult orElse()}) → TResult

Available on WireGuardPeerConfig, provided by the WireGuardPeerConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? publicKey, String? preSharedKey, String? endpoint, int? keepAlive, List<String>? allowedIPs)) → TResult

Available on WireGuardPeerConfig, provided by the WireGuardPeerConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? publicKey, String? preSharedKey, String? endpoint, int? keepAlive, List<String>? allowedIPs)?) → TResult?

Available on WireGuardPeerConfig, provided by the WireGuardPeerConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited