WireGuardPeerConfigPatterns extension

Adds pattern-matching-related methods to WireGuardPeerConfig.

on

Methods

map<TResult extends Object?>(TResult $default(_WireGuardPeerConfig value)) → TResult

Available on WireGuardPeerConfig, provided by the WireGuardPeerConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_WireGuardPeerConfig value)?) → TResult?

Available on WireGuardPeerConfig, provided by the WireGuardPeerConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_WireGuardPeerConfig value)?, {required TResult orElse()}) → TResult

Available on WireGuardPeerConfig, provided by the WireGuardPeerConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? publicKey, String? preSharedKey, String? endpoint, int? keepAlive, List<String>? allowedIPs)?, {required TResult orElse()}) → TResult

Available on WireGuardPeerConfig, provided by the WireGuardPeerConfigPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String? publicKey, String? preSharedKey, String? endpoint, int? keepAlive, List<String>? allowedIPs)) → TResult

Available on WireGuardPeerConfig, provided by the WireGuardPeerConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? publicKey, String? preSharedKey, String? endpoint, int? keepAlive, List<String>? allowedIPs)?) → TResult?

Available on WireGuardPeerConfig, provided by the WireGuardPeerConfigPatterns extension

A variant of when that fallback to returning null