Xdns class abstract

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

Xdns({Object? domain, List<String>? domains, List<String>? resolvers})
const
factory
Xdns.fromJson(Object? json)
factory

Properties

copyWith → $XdnsCopyWith<Xdns>
Create a copy of Xdns with the given fields replaced by the non-null parameter values.
no setterinherited
domain Object?
no setterinherited
domains List<String>?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
resolvers List<String>?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Xdns value)) → TResult

Available on Xdns, provided by the XdnsPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Xdns value)?) → TResult?

Available on Xdns, provided by the XdnsPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Xdns value)?, {required TResult orElse()}) → TResult

Available on Xdns, provided by the XdnsPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(Object? domain, List<String>? domains, List<String>? resolvers)?, {required TResult orElse()}) → TResult

Available on Xdns, provided by the XdnsPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(Object? domain, List<String>? domains, List<String>? resolvers)) → TResult

Available on Xdns, provided by the XdnsPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(Object? domain, List<String>? domains, List<String>? resolvers)?) → TResult?

Available on Xdns, provided by the XdnsPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited