Xicmp class abstract

Implemented types
Available extensions
Annotations
  • @freezed

Constructors

Xicmp({String? listenIp, int? id})
const
factory
Xicmp.fromJson(Object? json)
factory

Properties

copyWith → $XicmpCopyWith<Xicmp>
Create a copy of Xicmp with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int?
no setterinherited
listenIp String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Xicmp value)) → TResult

Available on Xicmp, provided by the XicmpPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Xicmp value)?) → TResult?

Available on Xicmp, provided by the XicmpPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Xicmp value)?, {required TResult orElse()}) → TResult

Available on Xicmp, provided by the XicmpPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? listenIp, int? id)?, {required TResult orElse()}) → TResult

Available on Xicmp, provided by the XicmpPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? listenIp, int? id)) → TResult

Available on Xicmp, provided by the XicmpPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? listenIp, int? id)?) → TResult?

Available on Xicmp, provided by the XicmpPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited