XmuxConfig class abstract

Available extensions
Annotations
  • @freezed

Constructors

XmuxConfig({XrayInt32Range? maxConcurrency, XrayInt32Range? maxConnections, XrayInt32Range? cMaxReuseTimes, XrayInt32Range? hMaxRequestTimes, XrayInt32Range? hMaxReusableSecs, int? hKeepAlivePeriod})
const
factory
XmuxConfig.fromJson(Object? json)
factory

Properties

cMaxReuseTimes XrayInt32Range?
no setterinherited
copyWith → $XmuxConfigCopyWith<XmuxConfig>
Create a copy of XmuxConfig with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hKeepAlivePeriod int?
no setterinherited
hMaxRequestTimes XrayInt32Range?
no setterinherited
hMaxReusableSecs XrayInt32Range?
no setterinherited
maxConcurrency XrayInt32Range?
no setterinherited
maxConnections XrayInt32Range?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_XmuxConfig value)) → TResult

Available on XmuxConfig, provided by the XmuxConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_XmuxConfig value)?) → TResult?

Available on XmuxConfig, provided by the XmuxConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_XmuxConfig value)?, {required TResult orElse()}) → TResult

Available on XmuxConfig, provided by the XmuxConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(XrayInt32Range? maxConcurrency, XrayInt32Range? maxConnections, XrayInt32Range? cMaxReuseTimes, XrayInt32Range? hMaxRequestTimes, XrayInt32Range? hMaxReusableSecs, int? hKeepAlivePeriod)?, {required TResult orElse()}) → TResult

Available on XmuxConfig, provided by the XmuxConfigPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(XrayInt32Range? maxConcurrency, XrayInt32Range? maxConnections, XrayInt32Range? cMaxReuseTimes, XrayInt32Range? hMaxRequestTimes, XrayInt32Range? hMaxReusableSecs, int? hKeepAlivePeriod)) → TResult

Available on XmuxConfig, provided by the XmuxConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(XrayInt32Range? maxConcurrency, XrayInt32Range? maxConnections, XrayInt32Range? cMaxReuseTimes, XrayInt32Range? hMaxRequestTimes, XrayInt32Range? hMaxReusableSecs, int? hKeepAlivePeriod)?) → TResult?

Available on XmuxConfig, provided by the XmuxConfigPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited