XrayInt32Range class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- XrayInt32Range({required int left, required int right})
-
constfactory
- XrayInt32Range.fromJson(Object? json)
-
factory
- XrayInt32Range.single(int value)
-
factory
Properties
-
copyWith
→ $XrayInt32RangeCopyWith<
XrayInt32Range> -
Create a copy of XrayInt32Range
with the given fields replaced by the non-null parameter values.
no setterinherited
- from → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- left → int
-
no setterinherited
- right → int
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- to → int
-
no setter
Methods
-
map<
TResult extends Object?> (TResult $default(_XrayInt32Range value)) → TResult -
Available on XrayInt32Range, provided by the XrayInt32RangePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_XrayInt32Range value)?) → TResult? -
Available on XrayInt32Range, provided by the XrayInt32RangePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_XrayInt32Range value)?, {required TResult orElse()}) → TResult -
Available on XrayInt32Range, provided by the XrayInt32RangePatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(int left, int right)?, {required TResult orElse()}) → TResult -
Available on XrayInt32Range, provided by the XrayInt32RangePatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(int left, int right)) → TResult -
Available on XrayInt32Range, provided by the XrayInt32RangePatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(int left, int right)?) → TResult? -
Available on XrayInt32Range, provided by the XrayInt32RangePatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited