XrayTargetStrategy enum

Inheritance
Available extensions

Values

asIs → const XrayTargetStrategy
useIp → const XrayTargetStrategy
useIpv4 → const XrayTargetStrategy
useIpv6 → const XrayTargetStrategy
useIpv4v6 → const XrayTargetStrategy
useIpv6v4 → const XrayTargetStrategy
forceIp → const XrayTargetStrategy
forceIpv4 → const XrayTargetStrategy
forceIpv6 → const XrayTargetStrategy
forceIpv4v6 → const XrayTargetStrategy
forceIpv6v4 → const XrayTargetStrategy

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String

Available on XrayTargetStrategy, provided by the XrayTargetStrategyJson extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<XrayTargetStrategy>
A constant List of the values in this enum, in order of their declaration.