XrayUser class abstract
- Available extensions
- Annotations
-
- @freezed
Properties
-
copyWith
→ $XrayUserCopyWith<
XrayUser> -
Create a copy of XrayUser
with the given fields replaced by the non-null parameter values.
no setterinherited
- email → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- level → int?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_XrayUser value)) → TResult -
Available on XrayUser, provided by the XrayUserPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_XrayUser value)?) → TResult? -
Available on XrayUser, provided by the XrayUserPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_XrayUser value)?, {required TResult orElse()}) → TResult -
Available on XrayUser, provided by the XrayUserPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? email, int? level)?, {required TResult orElse()}) → TResult -
Available on XrayUser, provided by the XrayUserPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? email, int? level)) → TResult -
Available on XrayUser, provided by the XrayUserPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? email, int? level)?) → TResult? -
Available on XrayUser, provided by the XrayUserPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited