DNSOutboundConfig class abstract
- Implemented types
- Available extensions
- Annotations
-
- @freezed
Constructors
-
DNSOutboundConfig({XrayNetwork? network, XrayAddress? address, int? port, int? userLevel, List<
DNSOutboundRuleConfig> ? rules, String? nonIPQuery, List<int> ? blockTypes}) -
constfactory
- DNSOutboundConfig.fromJson(Object? json)
-
factory
Properties
- address → XrayAddress?
-
no setterinherited
-
blockTypes
→ List<
int> ? -
no setterinherited
-
copyWith
→ $DNSOutboundConfigCopyWith<
DNSOutboundConfig> -
Create a copy of DNSOutboundConfig
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- network → XrayNetwork?
-
no setterinherited
- nonIPQuery → String?
-
no setterinherited
- port → int?
-
no setterinherited
-
rules
→ List<
DNSOutboundRuleConfig> ? -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userLevel → int?
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_DNSOutboundConfig value)) → TResult -
Available on DNSOutboundConfig, provided by the DNSOutboundConfigPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_DNSOutboundConfig value)?) → TResult? -
Available on DNSOutboundConfig, provided by the DNSOutboundConfigPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_DNSOutboundConfig value)?, {required TResult orElse()}) → TResult -
Available on DNSOutboundConfig, provided by the DNSOutboundConfigPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(XrayNetwork? network, XrayAddress? address, int? port, int? userLevel, List< DNSOutboundRuleConfig> ? rules, String? nonIPQuery, List<int> ? blockTypes)?, {required TResult orElse()}) → TResult -
Available on DNSOutboundConfig, provided by the DNSOutboundConfigPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(XrayNetwork? network, XrayAddress? address, int? port, int? userLevel, List< DNSOutboundRuleConfig> ? rules, String? nonIPQuery, List<int> ? blockTypes)) → TResult -
Available on DNSOutboundConfig, provided by the DNSOutboundConfigPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(XrayNetwork? network, XrayAddress? address, int? port, int? userLevel, List< DNSOutboundRuleConfig> ? rules, String? nonIPQuery, List<int> ? blockTypes)?) → TResult? -
Available on DNSOutboundConfig, provided by the DNSOutboundConfigPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited