HysteriaConfig class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- HysteriaConfig({required int version, String? auth, String? congestion, Bandwidth? up, Bandwidth? down, @JsonKey.new(name: 'udphop') UdpHop? udpHop, int? udpIdleTimeout, Masquerade? masquerade})
-
constfactory
- HysteriaConfig.fromJson(Object? json)
-
factory
Properties
- auth → String?
-
no setterinherited
- congestion → String?
-
no setterinherited
-
copyWith
→ $HysteriaConfigCopyWith<
HysteriaConfig> -
Create a copy of HysteriaConfig
with the given fields replaced by the non-null parameter values.
no setterinherited
- down → Bandwidth?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- masquerade → Masquerade?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- udpHop → UdpHop?
-
no setterinherited
- udpIdleTimeout → int?
-
no setterinherited
- up → Bandwidth?
-
no setterinherited
- version → int
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_HysteriaConfig value)) → TResult -
Available on HysteriaConfig, provided by the HysteriaConfigPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_HysteriaConfig value)?) → TResult? -
Available on HysteriaConfig, provided by the HysteriaConfigPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_HysteriaConfig value)?, {required TResult orElse()}) → TResult -
Available on HysteriaConfig, provided by the HysteriaConfigPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(int version, String? auth, String? congestion, Bandwidth? up, Bandwidth? down, UdpHop? udpHop, int? udpIdleTimeout, Masquerade? masquerade)?, {required TResult orElse()}) → TResult -
Available on HysteriaConfig, provided by the HysteriaConfigPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(int version, String? auth, String? congestion, Bandwidth? up, Bandwidth? down, UdpHop? udpHop, int? udpIdleTimeout, Masquerade? masquerade)) → TResult -
Available on HysteriaConfig, provided by the HysteriaConfigPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(int version, String? auth, String? congestion, Bandwidth? up, Bandwidth? down, UdpHop? udpHop, int? udpIdleTimeout, Masquerade? masquerade)?) → TResult? -
Available on HysteriaConfig, provided by the HysteriaConfigPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited