KCPConfig class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
Properties
-
copyWith
→ $KCPConfigCopyWith<
KCPConfig> -
Create a copy of KCPConfig
with the given fields replaced by the non-null parameter values.
no setterinherited
- cwndMultiplier → int?
-
no setterinherited
- downCap → int?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
header
→ Map<
String, dynamic> ? -
no setterinherited
- maxSendingWindow → int?
-
no setterinherited
- mtu → int?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seed → String?
-
no setterinherited
- tti → int?
-
no setterinherited
- upCap → int?
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_KCPConfig value)) → TResult -
Available on KCPConfig, provided by the KCPConfigPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_KCPConfig value)?) → TResult? -
Available on KCPConfig, provided by the KCPConfigPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_KCPConfig value)?, {required TResult orElse()}) → TResult -
Available on KCPConfig, provided by the KCPConfigPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(int? mtu, int? tti, int? upCap, int? downCap, int? cwndMultiplier, int? maxSendingWindow, Map< String, dynamic> ? header, String? seed)?, {required TResult orElse()}) → TResult -
Available on KCPConfig, provided by the KCPConfigPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(int? mtu, int? tti, int? upCap, int? downCap, int? cwndMultiplier, int? maxSendingWindow, Map< String, dynamic> ? header, String? seed)) → TResult -
Available on KCPConfig, provided by the KCPConfigPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(int? mtu, int? tti, int? upCap, int? downCap, int? cwndMultiplier, int? maxSendingWindow, Map< String, dynamic> ? header, String? seed)?) → TResult? -
Available on KCPConfig, provided by the KCPConfigPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited