LogConfig class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
Properties
- access → String?
-
no setterinherited
-
copyWith
→ $LogConfigCopyWith<
LogConfig> -
Create a copy of LogConfig
with the given fields replaced by the non-null parameter values.
no setterinherited
- dnsLog → bool?
-
no setterinherited
- error → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- loglevel → LogLevel?
-
no setterinherited
- maskAddress → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_LogConfig value)) → TResult -
Available on LogConfig, provided by the LogConfigPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_LogConfig value)?) → TResult? -
Available on LogConfig, provided by the LogConfigPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_LogConfig value)?, {required TResult orElse()}) → TResult -
Available on LogConfig, provided by the LogConfigPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? access, String? error, LogLevel? loglevel, bool? dnsLog, String? maskAddress)?, {required TResult orElse()}) → TResult -
Available on LogConfig, provided by the LogConfigPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? access, String? error, LogLevel? loglevel, bool? dnsLog, String? maskAddress)) → TResult -
Available on LogConfig, provided by the LogConfigPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? access, String? error, LogLevel? loglevel, bool? dnsLog, String? maskAddress)?) → TResult? -
Available on LogConfig, provided by the LogConfigPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited