Policy class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
Properties
- bufferSize → int?
-
no setterinherited
- connectionIdle → int?
-
no setterinherited
-
copyWith
→ $PolicyCopyWith<
Policy> -
Create a copy of Policy
with the given fields replaced by the non-null parameter values.
no setterinherited
- downlinkOnly → int?
-
no setterinherited
- handshake → int?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statsUserDownlink → bool?
-
no setterinherited
- statsUserOnline → bool?
-
no setterinherited
- statsUserUplink → bool?
-
no setterinherited
- uplinkOnly → int?
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_Policy value)) → TResult -
Available on Policy, provided by the PolicyPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_Policy value)?) → TResult? -
Available on Policy, provided by the PolicyPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_Policy value)?, {required TResult orElse()}) → TResult -
Available on Policy, provided by the PolicyPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(int? handshake, int? connectionIdle, int? uplinkOnly, int? downlinkOnly, bool? statsUserUplink, bool? statsUserDownlink, bool? statsUserOnline, int? bufferSize)?, {required TResult orElse()}) → TResult -
Available on Policy, provided by the PolicyPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(int? handshake, int? connectionIdle, int? uplinkOnly, int? downlinkOnly, bool? statsUserUplink, bool? statsUserDownlink, bool? statsUserOnline, int? bufferSize)) → TResult -
Available on Policy, provided by the PolicyPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(int? handshake, int? connectionIdle, int? uplinkOnly, int? downlinkOnly, bool? statsUserUplink, bool? statsUserDownlink, bool? statsUserOnline, int? bufferSize)?) → TResult? -
Available on Policy, provided by the PolicyPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited