ShadowsocksClientConfig class abstract
- Implemented types
- Available extensions
- Annotations
-
- @freezed
Constructors
-
ShadowsocksClientConfig({XrayAddress? address, int? port, int? level, String? email, @JsonKey.new(name: 'method') String? cipher, String? password, bool? uot, int? uotVersion, List<
ShadowsocksServerTarget> ? servers}) -
constfactory
- ShadowsocksClientConfig.fromJson(Object? json)
-
factory
- ShadowsocksClientConfig.single({required XrayAddress address, required int port, int? level, String? email, required String cipher, required String password, bool? uot, int? uotVersion})
-
factory
Properties
- address → XrayAddress?
-
no setterinherited
- cipher → String?
-
no setterinherited
-
copyWith
→ $ShadowsocksClientConfigCopyWith<
ShadowsocksClientConfig> -
Create a copy of ShadowsocksClientConfig
with the given fields replaced by the non-null parameter values.
no setterinherited
- email → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- level → int?
-
no setterinherited
- password → String?
-
no setterinherited
- port → int?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
servers
→ List<
ShadowsocksServerTarget> ? -
no setterinherited
- uot → bool?
-
no setterinherited
- uotVersion → int?
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_ShadowsocksClientConfig value)) → TResult -
Available on ShadowsocksClientConfig, provided by the ShadowsocksClientConfigPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_ShadowsocksClientConfig value)?) → TResult? -
Available on ShadowsocksClientConfig, provided by the ShadowsocksClientConfigPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_ShadowsocksClientConfig value)?, {required TResult orElse()}) → TResult -
Available on ShadowsocksClientConfig, provided by the ShadowsocksClientConfigPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(XrayAddress? address, int? port, int? level, String? email, String? cipher, String? password, bool? uot, int? uotVersion, List< ShadowsocksServerTarget> ? servers)?, {required TResult orElse()}) → TResult -
Available on ShadowsocksClientConfig, provided by the ShadowsocksClientConfigPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(XrayAddress? address, int? port, int? level, String? email, String? cipher, String? password, bool? uot, int? uotVersion, List< ShadowsocksServerTarget> ? servers)) → TResult -
Available on ShadowsocksClientConfig, provided by the ShadowsocksClientConfigPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(XrayAddress? address, int? port, int? level, String? email, String? cipher, String? password, bool? uot, int? uotVersion, List< ShadowsocksServerTarget> ? servers)?) → TResult? -
Available on ShadowsocksClientConfig, provided by the ShadowsocksClientConfigPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited