SocksRemoteConfig class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
SocksRemoteConfig({required XrayAddress address, required int port, List<
SocksAccount> ? users}) -
constfactory
- SocksRemoteConfig.fromJson(Object? json)
-
factory
Properties
- address → XrayAddress
-
no setterinherited
-
copyWith
→ $SocksRemoteConfigCopyWith<
SocksRemoteConfig> -
Create a copy of SocksRemoteConfig
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- port → int
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
users
→ List<
SocksAccount> ? -
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_SocksRemoteConfig value)) → TResult -
Available on SocksRemoteConfig, provided by the SocksRemoteConfigPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_SocksRemoteConfig value)?) → TResult? -
Available on SocksRemoteConfig, provided by the SocksRemoteConfigPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_SocksRemoteConfig value)?, {required TResult orElse()}) → TResult -
Available on SocksRemoteConfig, provided by the SocksRemoteConfigPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(XrayAddress address, int port, List< SocksAccount> ? users)?, {required TResult orElse()}) → TResult -
Available on SocksRemoteConfig, provided by the SocksRemoteConfigPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(XrayAddress address, int port, List< SocksAccount> ? users)) → TResult -
Available on SocksRemoteConfig, provided by the SocksRemoteConfigPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(XrayAddress address, int port, List< SocksAccount> ? users)?) → TResult? -
Available on SocksRemoteConfig, provided by the SocksRemoteConfigPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited