StreamConfig class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- StreamConfig({XrayAddress? address, int? port, TransportProtocol? network, SecurityProtocol? security, FinalMask? finalmask, TCPConfig? rawSettings, TCPConfig? tcpSettings, SplitHTTPConfig? xhttpSettings, KCPConfig? kcpSettings, WebSocketConfig? wsSettings, HttpUpgradeConfig? httpupgradeSettings, SplitHTTPConfig? splithttpSettings, GRPCConfig? grpcSettings, HysteriaConfig? hysteriaSettings, TLSConfig? tlsSettings, REALITYConfig? realitySettings, SocketConfig? sockopt})
-
constfactory
- StreamConfig.fromJson(Object? json)
-
factory
- StreamConfig.reality({TransportProtocol network = TransportProtocol.tcp, required REALITYConfig realitySettings, TCPConfig? rawSettings, TCPConfig? tcpSettings, SplitHTTPConfig? xhttpSettings, SplitHTTPConfig? splithttpSettings, GRPCConfig? grpcSettings, SocketConfig? sockopt})
-
factory
- StreamConfig.tls({TransportProtocol? network, TLSConfig? tlsSettings, TCPConfig? rawSettings, TCPConfig? tcpSettings, SplitHTTPConfig? xhttpSettings, KCPConfig? kcpSettings, WebSocketConfig? wsSettings, HttpUpgradeConfig? httpupgradeSettings, SplitHTTPConfig? splithttpSettings, GRPCConfig? grpcSettings, HysteriaConfig? hysteriaSettings, SocketConfig? sockopt})
-
factory
Properties
- address → XrayAddress?
-
no setterinherited
-
copyWith
→ $StreamConfigCopyWith<
StreamConfig> -
Create a copy of StreamConfig
with the given fields replaced by the non-null parameter values.
no setterinherited
- finalmask → FinalMask?
-
no setterinherited
- grpcSettings → GRPCConfig?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpupgradeSettings → HttpUpgradeConfig?
-
no setterinherited
- hysteriaSettings → HysteriaConfig?
-
no setterinherited
- kcpSettings → KCPConfig?
-
no setterinherited
- network → TransportProtocol?
-
no setterinherited
- port → int?
-
no setterinherited
- rawSettings → TCPConfig?
-
no setterinherited
- realitySettings → REALITYConfig?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- security → SecurityProtocol?
-
no setterinherited
- sockopt → SocketConfig?
-
no setterinherited
- splithttpSettings → SplitHTTPConfig?
-
no setterinherited
- tcpSettings → TCPConfig?
-
no setterinherited
- tlsSettings → TLSConfig?
-
no setterinherited
- wsSettings → WebSocketConfig?
-
no setterinherited
- xhttpSettings → SplitHTTPConfig?
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_StreamConfig value)) → TResult -
Available on StreamConfig, provided by the StreamConfigPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_StreamConfig value)?) → TResult? -
Available on StreamConfig, provided by the StreamConfigPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_StreamConfig value)?, {required TResult orElse()}) → TResult -
Available on StreamConfig, provided by the StreamConfigPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(XrayAddress? address, int? port, TransportProtocol? network, SecurityProtocol? security, FinalMask? finalmask, TCPConfig? rawSettings, TCPConfig? tcpSettings, SplitHTTPConfig? xhttpSettings, KCPConfig? kcpSettings, WebSocketConfig? wsSettings, HttpUpgradeConfig? httpupgradeSettings, SplitHTTPConfig? splithttpSettings, GRPCConfig? grpcSettings, HysteriaConfig? hysteriaSettings, TLSConfig? tlsSettings, REALITYConfig? realitySettings, SocketConfig? sockopt)?, {required TResult orElse()}) → TResult -
Available on StreamConfig, provided by the StreamConfigPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(XrayAddress? address, int? port, TransportProtocol? network, SecurityProtocol? security, FinalMask? finalmask, TCPConfig? rawSettings, TCPConfig? tcpSettings, SplitHTTPConfig? xhttpSettings, KCPConfig? kcpSettings, WebSocketConfig? wsSettings, HttpUpgradeConfig? httpupgradeSettings, SplitHTTPConfig? splithttpSettings, GRPCConfig? grpcSettings, HysteriaConfig? hysteriaSettings, TLSConfig? tlsSettings, REALITYConfig? realitySettings, SocketConfig? sockopt)) → TResult -
Available on StreamConfig, provided by the StreamConfigPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(XrayAddress? address, int? port, TransportProtocol? network, SecurityProtocol? security, FinalMask? finalmask, TCPConfig? rawSettings, TCPConfig? tcpSettings, SplitHTTPConfig? xhttpSettings, KCPConfig? kcpSettings, WebSocketConfig? wsSettings, HttpUpgradeConfig? httpupgradeSettings, SplitHTTPConfig? splithttpSettings, GRPCConfig? grpcSettings, HysteriaConfig? hysteriaSettings, TLSConfig? tlsSettings, REALITYConfig? realitySettings, SocketConfig? sockopt)?) → TResult? -
Available on StreamConfig, provided by the StreamConfigPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited