TLSCertConfig class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
TLSCertConfig({@JsonKey.new(name: 'certificateFile') String? certFile, @JsonKey.new(name: 'certificate') List<
String> ? certStr, String? keyFile, @JsonKey.new(name: 'key') List<String> ? keyStr, TLSCertificateUsage? usage, int? ocspStapling, bool? oneTimeLoading, bool? buildChain}) -
constfactory
- TLSCertConfig.fromJson(Object? json)
-
factory
Properties
- buildChain → bool?
-
no setterinherited
- certFile → String?
-
no setterinherited
-
certStr
→ List<
String> ? -
no setterinherited
-
copyWith
→ $TLSCertConfigCopyWith<
TLSCertConfig> -
Create a copy of TLSCertConfig
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyFile → String?
-
no setterinherited
-
keyStr
→ List<
String> ? -
no setterinherited
- ocspStapling → int?
-
no setterinherited
- oneTimeLoading → bool?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- usage → TLSCertificateUsage?
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_TLSCertConfig value)) → TResult -
Available on TLSCertConfig, provided by the TLSCertConfigPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_TLSCertConfig value)?) → TResult? -
Available on TLSCertConfig, provided by the TLSCertConfigPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_TLSCertConfig value)?, {required TResult orElse()}) → TResult -
Available on TLSCertConfig, provided by the TLSCertConfigPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? certFile, List< String> ? certStr, String? keyFile, List<String> ? keyStr, TLSCertificateUsage? usage, int? ocspStapling, bool? oneTimeLoading, bool? buildChain)?, {required TResult orElse()}) → TResult -
Available on TLSCertConfig, provided by the TLSCertConfigPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? certFile, List< String> ? certStr, String? keyFile, List<String> ? keyStr, TLSCertificateUsage? usage, int? ocspStapling, bool? oneTimeLoading, bool? buildChain)) → TResult -
Available on TLSCertConfig, provided by the TLSCertConfigPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? certFile, List< String> ? certStr, String? keyFile, List<String> ? keyStr, TLSCertificateUsage? usage, int? ocspStapling, bool? oneTimeLoading, bool? buildChain)?) → TResult? -
Available on TLSCertConfig, provided by the TLSCertConfigPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited