TrojanInboundFallback class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- TrojanInboundFallback({String? name, String? alpn, String? path, XrayFallbackType? type, Object? dest, int? xver})
-
constfactory
- TrojanInboundFallback.fromJson(Object? json)
-
factory
Properties
- alpn → String?
-
no setterinherited
-
copyWith
→ $TrojanInboundFallbackCopyWith<
TrojanInboundFallback> -
Create a copy of TrojanInboundFallback
with the given fields replaced by the non-null parameter values.
no setterinherited
- dest → Object?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
no setterinherited
- path → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → XrayFallbackType?
-
no setterinherited
- xver → int?
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_TrojanInboundFallback value)) → TResult -
Available on TrojanInboundFallback, provided by the TrojanInboundFallbackPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_TrojanInboundFallback value)?) → TResult? -
Available on TrojanInboundFallback, provided by the TrojanInboundFallbackPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_TrojanInboundFallback value)?, {required TResult orElse()}) → TResult -
Available on TrojanInboundFallback, provided by the TrojanInboundFallbackPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? name, String? alpn, String? path, XrayFallbackType? type, Object? dest, int? xver)?, {required TResult orElse()}) → TResult -
Available on TrojanInboundFallback, provided by the TrojanInboundFallbackPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? name, String? alpn, String? path, XrayFallbackType? type, Object? dest, int? xver)) → TResult -
Available on TrojanInboundFallback, provided by the TrojanInboundFallbackPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? name, String? alpn, String? path, XrayFallbackType? type, Object? dest, int? xver)?) → TResult? -
Available on TrojanInboundFallback, provided by the TrojanInboundFallbackPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited