TunConfig class abstract
- Implemented types
- Available extensions
- Annotations
-
- @freezed
Constructors
Properties
- autoOutboundsInterface → String?
-
no setterinherited
-
autoSystemRoutingTable
→ List<
String> ? -
no setterinherited
-
copyWith
→ $TunConfigCopyWith<
TunConfig> -
Create a copy of TunConfig
with the given fields replaced by the non-null parameter values.
no setterinherited
-
dns
→ List<
String> ? -
no setterinherited
-
gateway
→ List<
String> ? -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- mtu → int?
-
no setterinherited
- name → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userLevel → int?
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_TunConfig value)) → TResult -
Available on TunConfig, provided by the TunConfigPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_TunConfig value)?) → TResult? -
Available on TunConfig, provided by the TunConfigPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_TunConfig value)?, {required TResult orElse()}) → TResult -
Available on TunConfig, provided by the TunConfigPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? name, int? mtu, List< String> ? gateway, List<String> ? dns, int? userLevel, List<String> ? autoSystemRoutingTable, String? autoOutboundsInterface)?, {required TResult orElse()}) → TResult -
Available on TunConfig, provided by the TunConfigPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? name, int? mtu, List< String> ? gateway, List<String> ? dns, int? userLevel, List<String> ? autoSystemRoutingTable, String? autoOutboundsInterface)) → TResult -
Available on TunConfig, provided by the TunConfigPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? name, int? mtu, List< String> ? gateway, List<String> ? dns, int? userLevel, List<String> ? autoSystemRoutingTable, String? autoOutboundsInterface)?) → TResult? -
Available on TunConfig, provided by the TunConfigPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited