VLessOutboundConfig class abstract
- Implemented types
- Available extensions
- Annotations
-
- @freezed
Constructors
-
VLessOutboundConfig({XrayAddress? address, int? port, int? level, String? email, @JsonKey.new(name: 'id') String? id, String? flow, String? seed, String? encryption, VLessReverseConfig? reverse, int? testpre, List<
int> ? testseed, @JsonKey.new(name: 'vnext') List<VLessOutboundVnext> ? vnext}) -
constfactory
- VLessOutboundConfig.fromJson(Object? json)
-
factory
-
VLessOutboundConfig.single({required XrayAddress address, required int port, int? level, String? email, required String id, String? flow, String? seed, required String encryption, VLessReverseConfig? reverse, int? testpre, List<
int> ? testseed}) -
factory
Properties
- address → XrayAddress?
-
no setterinherited
-
copyWith
→ $VLessOutboundConfigCopyWith<
VLessOutboundConfig> -
Create a copy of VLessOutboundConfig
with the given fields replaced by the non-null parameter values.
no setterinherited
- email → String?
-
no setterinherited
- encryption → String?
-
no setterinherited
- flow → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
no setterinherited
- level → int?
-
no setterinherited
- port → int?
-
no setterinherited
- reverse → VLessReverseConfig?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seed → String?
-
no setterinherited
- testpre → int?
-
no setterinherited
-
testseed
→ List<
int> ? -
no setterinherited
-
vnext
→ List<
VLessOutboundVnext> ? -
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_VLessOutboundConfig value)) → TResult -
Available on VLessOutboundConfig, provided by the VLessOutboundConfigPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_VLessOutboundConfig value)?) → TResult? -
Available on VLessOutboundConfig, provided by the VLessOutboundConfigPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_VLessOutboundConfig value)?, {required TResult orElse()}) → TResult -
Available on VLessOutboundConfig, provided by the VLessOutboundConfigPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(XrayAddress? address, int? port, int? level, String? email, String? id, String? flow, String? seed, String? encryption, VLessReverseConfig? reverse, int? testpre, List< int> ? testseed, List<VLessOutboundVnext> ? vnext)?, {required TResult orElse()}) → TResult -
Available on VLessOutboundConfig, provided by the VLessOutboundConfigPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(XrayAddress? address, int? port, int? level, String? email, String? id, String? flow, String? seed, String? encryption, VLessReverseConfig? reverse, int? testpre, List< int> ? testseed, List<VLessOutboundVnext> ? vnext)) → TResult -
Available on VLessOutboundConfig, provided by the VLessOutboundConfigPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(XrayAddress? address, int? port, int? level, String? email, String? id, String? flow, String? seed, String? encryption, VLessReverseConfig? reverse, int? testpre, List< int> ? testseed, List<VLessOutboundVnext> ? vnext)?) → TResult? -
Available on VLessOutboundConfig, provided by the VLessOutboundConfigPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited