VMessOutboundConfig class abstract
- Implemented types
- Available extensions
- Annotations
-
- @freezed
Constructors
-
VMessOutboundConfig({XrayAddress? address, int? port, int? level, String? email, String? id, VmessSecurity? security, String? experiments, @JsonKey.new(name: 'vnext') List<
VMessOutboundTarget> ? receivers}) -
constfactory
- VMessOutboundConfig.fromJson(Object? json)
-
factory
- VMessOutboundConfig.single({required XrayAddress address, required int port, int? level, String? email, required String id, VmessSecurity? security, String? experiments})
-
factory
Properties
- address → XrayAddress?
-
no setterinherited
-
copyWith
→ $VMessOutboundConfigCopyWith<
VMessOutboundConfig> -
Create a copy of VMessOutboundConfig
with the given fields replaced by the non-null parameter values.
no setterinherited
- email → String?
-
no setterinherited
- experiments → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
no setterinherited
- level → int?
-
no setterinherited
- port → int?
-
no setterinherited
-
receivers
→ List<
VMessOutboundTarget> ? -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- security → VmessSecurity?
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_VMessOutboundConfig value)) → TResult -
Available on VMessOutboundConfig, provided by the VMessOutboundConfigPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_VMessOutboundConfig value)?) → TResult? -
Available on VMessOutboundConfig, provided by the VMessOutboundConfigPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_VMessOutboundConfig value)?, {required TResult orElse()}) → TResult -
Available on VMessOutboundConfig, provided by the VMessOutboundConfigPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(XrayAddress? address, int? port, int? level, String? email, String? id, VmessSecurity? security, String? experiments, List< VMessOutboundTarget> ? receivers)?, {required TResult orElse()}) → TResult -
Available on VMessOutboundConfig, provided by the VMessOutboundConfigPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(XrayAddress? address, int? port, int? level, String? email, String? id, VmessSecurity? security, String? experiments, List< VMessOutboundTarget> ? receivers)) → TResult -
Available on VMessOutboundConfig, provided by the VMessOutboundConfigPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(XrayAddress? address, int? port, int? level, String? email, String? id, VmessSecurity? security, String? experiments, List< VMessOutboundTarget> ? receivers)?) → TResult? -
Available on VMessOutboundConfig, provided by the VMessOutboundConfigPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited