VersionConfig class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
- VersionConfig({@JsonKey.new(name: 'min') String? minVersion, @JsonKey.new(name: 'max') String? maxVersion})
-
constfactory
- VersionConfig.fromJson(Object? json)
-
factory
Properties
-
copyWith
→ $VersionConfigCopyWith<
VersionConfig> -
Create a copy of VersionConfig
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxVersion → String?
-
no setterinherited
- minVersion → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_VersionConfig value)) → TResult -
Available on VersionConfig, provided by the VersionConfigPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_VersionConfig value)?) → TResult? -
Available on VersionConfig, provided by the VersionConfigPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_VersionConfig value)?, {required TResult orElse()}) → TResult -
Available on VersionConfig, provided by the VersionConfigPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? minVersion, String? maxVersion)?, {required TResult orElse()}) → TResult -
Available on VersionConfig, provided by the VersionConfigPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? minVersion, String? maxVersion)) → TResult -
Available on VersionConfig, provided by the VersionConfigPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? minVersion, String? maxVersion)?) → TResult? -
Available on VersionConfig, provided by the VersionConfigPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited