WebSocketConfig class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
WebSocketConfig({String? host, String? path, Map<
String, String> ? headers, bool? acceptProxyProtocol, int? heartbeatPeriod}) -
constfactory
- WebSocketConfig.fromJson(Object? json)
-
factory
Properties
- acceptProxyProtocol → bool?
-
no setterinherited
-
copyWith
→ $WebSocketConfigCopyWith<
WebSocketConfig> -
Create a copy of WebSocketConfig
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> ? -
no setterinherited
- heartbeatPeriod → int?
-
no setterinherited
- host → String?
-
no setterinherited
- path → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_WebSocketConfig value)) → TResult -
Available on WebSocketConfig, provided by the WebSocketConfigPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_WebSocketConfig value)?) → TResult? -
Available on WebSocketConfig, provided by the WebSocketConfigPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_WebSocketConfig value)?, {required TResult orElse()}) → TResult -
Available on WebSocketConfig, provided by the WebSocketConfigPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String? host, String? path, Map< String, String> ? headers, bool? acceptProxyProtocol, int? heartbeatPeriod)?, {required TResult orElse()}) → TResult -
Available on WebSocketConfig, provided by the WebSocketConfigPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String? host, String? path, Map< String, String> ? headers, bool? acceptProxyProtocol, int? heartbeatPeriod)) → TResult -
Available on WebSocketConfig, provided by the WebSocketConfigPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String? host, String? path, Map< String, String> ? headers, bool? acceptProxyProtocol, int? heartbeatPeriod)?) → TResult? -
Available on WebSocketConfig, provided by the WebSocketConfigPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited