XrayOutboundProtocol enum
Values
- block → const XrayOutboundProtocol
- blackhole → const XrayOutboundProtocol
- loopback → const XrayOutboundProtocol
- direct → const XrayOutboundProtocol
- freedom → const XrayOutboundProtocol
- http → const XrayOutboundProtocol
- shadowsocks → const XrayOutboundProtocol
- socks → const XrayOutboundProtocol
- vless → const XrayOutboundProtocol
- vmess → const XrayOutboundProtocol
- trojan → const XrayOutboundProtocol
- hysteria → const XrayOutboundProtocol
- dns → const XrayOutboundProtocol
- wireguard → const XrayOutboundProtocol
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
XrayOutboundProtocol> - A constant List of the values in this enum, in order of their declaration.