XrayPortList class
Constructors
-
XrayPortList(List<
XrayPortRange> ranges) -
const
- XrayPortList.env(String name)
-
factory
- XrayPortList.fromJson(Object? json)
-
factory
- XrayPortList.range(int from, int to)
-
factory
- XrayPortList.single(int port)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ranges
→ List<
XrayPortRange> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited